@@ -11,8 +11,10 @@
  */
 
 var fs = require("fs");
-var http = require("http");
 var path = require("path");
+if (fs.existsSync) path.existsSync = fs.existsSync;
+
+var http = require("http");
 var readline = require('readline');
 var util = require("util");
 var utils = require("./lib/build/fileutils");
@@ -23,7 +25,7 @@ var ast = require("./lib/build/ast");
 var i18n = require("./lib/build/i18n");
 var rimraf = require("./lib/rimraf/rimraf");
 var jshint = require("./lib/jshint").JSHINT;
-var less = require("./lib/build/less");
+var less = require('./lib/build/less');
 
 console.info("Build path: " + utils.builddir);
 
@@ -59,6 +61,8 @@ function envBoolean(name) {
 }
 
 var debug = envBoolean('debug');
+var disableStrictMode = envBoolean('disableStrictMode');
+
 if (debug) console.info("Debug mode: on");
 
 utils.fileType("source").addHook("filter", utils.includeFilter);
@@ -92,6 +96,17 @@ function jsFilter (data) {
         data = hint.call(this, data, this.getSrc);
     }
 
+    // Check for NBSPs, Eclipse doesn't like them
+    if (data.indexOf('\xa0') >= 0) {
+        _.each(data.split(/\r\n?|\n/), function (line, lineno) {
+            var col = line.indexOf('\xa0');
+            if (col < 0) return;
+            var pos = self.getSrc(lineno + 1);
+            console.warn('Warning: NBSP in ' + pos.name + ' at ' + pos.line +
+                         ':' + (col + 1));
+        });
+    }
+
     var tree = parse(data, self.task.name);
 
     // Custom processing of the parsed AST
@@ -99,6 +114,15 @@ function jsFilter (data) {
     var defineHooks = this.type.getHooks("define");
     var tree2 = ast.scanner(defineWalker, defineHandler)
                    .scanner(defineAsyncWalker, defineHandler);
+    if (disableStrictMode) {
+        tree2 = tree2.scanner({
+            name: 'function',
+            matcher: strictModeMatcher
+        }, strictModeHandler).scanner({
+            name: 'defun',
+            matcher: strictModeMatcher
+        }, strictModeHandler);
+    }
     if (!debug) tree2 = tree2.scanner(assertWalker, assertHandler);
     tree = tree2.scan(pro.ast_add_scope(tree));
 
@@ -120,6 +144,17 @@ function jsFilter (data) {
             }
         }
         var deps = _.detect(args, ast.is("array"));
+        if (deps) {
+            _.each(deps[1], function(dep) {
+                dep = dep[1];
+                if (dep.slice(0, 5) !== 'less!') return;
+                dep = dep.slice(5);
+                if (!path.existsSync(path.join('apps', dep))) {
+                    console.warn('Missing LessCSS file ' + dep +
+                                 ' required by ' + mod);
+                }
+            });
+        }
         var f = _.detect(args, ast.is("function"));
         if (!name || !deps || !f) return;
         for (var i = 0; i < defineHooks.length; i++) {
@@ -129,17 +164,30 @@ function jsFilter (data) {
     function assertHandler(scope) {
         if (scope.refs.assert === undefined) return ['num', 0];
     }
+    function strictModeMatcher(tree) {
+        return tree[3] && tree[3][0] && tree[3][0][0] == 'stat' &&
+            tree[3][0][1] && tree[3][0][1][0] == 'string' &&
+            tree[3][0][1][1] == 'use strict';
+    }
+    function strictModeHandler(scope, walk) {
+        this[3][0][1][1] = 'no strict';
+        return [this[0], this[1], this[2].slice(), pro.MAP(this[3], walk)];
+    }
 
     // UglifyJS
-    if (debug) return data.slice(-1) === '\n' ? data : data + '\n';
-    tree = pro.ast_lift_variables(tree);
-    tree = pro.ast_mangle(tree);
-    tree = pro.ast_squeeze(tree, { make_seqs: false });
+    if (!disableStrictMode) {
+        if (debug) return data.slice(-1) === '\n' ? data : data + '\n';
+        tree = pro.ast_lift_variables(tree);
+        tree = pro.ast_mangle(tree);
+        tree = pro.ast_squeeze(tree, { make_seqs: false });
+    }
+
     // use split_lines
     return catchParseErrors(function (data) {
         return pro.split_lines(data, 500);
-    }, pro.gen_code(tree, { })) + ';';
+    }, pro.gen_code(tree, { beautify: debug })) + ';';
 }
+
 utils.fileType("source").addHook("filter", jsFilter)
     .addHook("define", i18n.potScanner);
 
@@ -165,7 +213,7 @@ var jshintOptions = {
     validthis: true,
     white: true, // THIS IS TURNED ON - otherwise we have too many dirty check-ins
     predef: ['$', '_', 'Modernizr', 'define', 'require', 'requirejs', 'ox', 'assert',
-             'include', 'doT', 'Backbone', 'BigScreen']
+             'include', 'doT', 'Backbone', 'BigScreen', 'tinyMCE']
 };
 
 function hint (data, getSrc) {
@@ -194,7 +242,7 @@ utils.topLevelTask('default', ['buildApp'], function() {
     utils.summary('default')();
 });
 
-utils.copy(utils.list("html", [".htaccess", "blank.html", "busy.html", "favicon.ico"]));
+utils.copy(utils.list("html", [".htaccess", "blank.html", "busy.html", "print.html", "favicon.ico"]));
 utils.copy(utils.list("src/"));
 
 //html
@@ -252,7 +300,6 @@ utils.concat("boot.js", [
         "lib/require.js",
         "lib/require-fix.js",
         "lib/modernizr.js",
-        "lib/jquery.lazyload.js",
         "lib/bigscreen.js",
         "lib/placeholder.min.js",
         //add backbone and dot.js may be a AMD-variant would be better
@@ -293,6 +340,21 @@ if (path.existsSync('help')) {
     });
 }
 
+// postinst utilities
+
+utils.concat('update-themes.js', utils.list('lib',
+    ['less.js/build/require-rhino.js',
+     'less.js/build/ecma-5.js',
+     'less.js/lib/less/parser.js',
+     'less.js/lib/less/functions.js',
+     'less.js/lib/less/colors.js',
+     'less.js/lib/less/tree/*.js',
+     'less.js/lib/less/tree.js',
+     'build/update-themes.js']),
+    { to: utils.dest('share') });
+utils.copy(utils.list('lib/build', 'update-themes.sh'),
+    { to: utils.dest('share') });
+
 // external apps
 
 desc('Builds an external app');
@@ -409,6 +471,46 @@ utils.merge('manifests/' + pkgName + '.json',
         }
     });
 
+// themes
+
+if (!envBoolean('skipLess')) {
+    
+    // own themes
+    _.each(utils.list('apps/themes/*/definitions.less'), function(defs) {
+        var dir = path.dirname(defs);
+        utils.concat(path.join(dir, 'less/common.css'),
+            [utils.dest('apps/themes/definitions.less'), defs,
+             utils.dest('apps/themes/style.less')],
+            { filter: less.compile });
+        utils.concat(path.join(dir, 'less/style.css'),
+            [utils.dest('apps/themes/definitions.less'), defs,
+             path.join(dir, 'style.less')],
+            { filter: less.compile });
+        _.each(utils.list('apps', '**/*.less'), function (file) {
+            if (file.slice(0, 7) === 'themes/') return;
+            utils.concat(path.join(dir, 'less', file),
+                [utils.dest('apps/themes/definitions.less'), defs,
+                 path.join('apps', file)],
+                 { filter: less.compile });
+        });
+    });
+    
+    // foreign themes
+    _.each(utils.list(utils.dest('apps/themes'), '*/definitions.less'),
+        function (defs) {
+            if (path.existsSync(path.join('apps/themes', defs))) return;
+            var dir = path.join('apps/themes', path.dirname(defs));
+            _.each(utils.list('apps', '**/*.less'), function (file) {
+                if (file.slice(0, 7) === 'themes/') return;
+                utils.concat(path.join(dir, 'less', file),
+                    [utils.dest('apps/themes/definitions.less'),
+                     utils.dest(path.join('apps/themes', defs)),
+                     path.join('apps', file)],
+                     { filter: less.compile });
+            });
+        });
+}
+
 // docs task
 
 desc("Generates developer documentation");
@@ -424,6 +526,7 @@ function docFile(file, title) {
 
 docFile("gettingStarted", "Getting Started");
 docFile("apache", "Apache Configuration");
+docFile("extensions", "Extension Points");
 docFile("extensionpoints_contact", "Extension Points / Contact App");
 docFile("extensionpoints_mail", "Extension Points / Mail App");
 docFile("libs", "External Libs");
@@ -626,11 +729,12 @@ task("dist", [distDest], function () {
     var dest = path.join(distDest, tarName);
     fs.mkdirSync(dest);
     utils.exec(["cp", "-r"].concat(toCopy, dest), tar);
-    function addL10n(spec) {
-        return spec.replace(/## l10n ##.*\n([\s\S]+?)^## end l10n ##.*/gm,
+    function replaceL10n(spec, key, languages) {
+        return spec.replace(
+            new RegExp('## ' + key + ' ##.*\\n([\\s\\S]+?)^## end ##.*', 'gm'),
             function (m, block) {
                 block = block.replace(/^#/gm, '');
-                return _.map(i18n.languages(), function (Lang) {
+                return _.map(languages, function (Lang) {
                     var lang = Lang.toLowerCase().replace(/_/g, '-');
                     return block.replace(/## ([Ll])ang ##/g, function (m, L) {
                         return L === 'L' ? Lang : lang;
@@ -638,12 +742,20 @@ task("dist", [distDest], function () {
                 }).join('\n');
             });
     }
+    function addL10n(spec) {
+        spec = replaceL10n(spec, 'l10n', i18n.languages());
+        if (path.existsSync('help')) {
+            spec = replaceL10n(spec, 'help', fs.readdirSync('help'));
+        }
+        return spec;
+    }
     function tar(code) {
-        if (code) return fail();
+        if (code) return fail('cp exited with code ' + code);
 
         var file = path.join(dest, pkgName + '.spec');
         fs.writeFileSync(file, addL10n(fs.readFileSync(file, 'utf8')
-            .replace(/^(Version:\s*)\S+/gm, '$01' + ver)));
+            .replace(/^(Version:\s*)\S+/gm, '$01' + ver)
+            .replace(/^(%define\s+ox_release\s+)\S+/gm, '$01' + rev)));
         file = path.join(dest, 'debian/control');
         fs.writeFileSync(file, addL10n(fs.readFileSync(file, 'utf8')));
 
@@ -652,6 +764,7 @@ task("dist", [distDest], function () {
                 JSON.parse(fs.readFileSync('i18n/languagenames.json', 'utf8')),
                 JSON.parse(fs.readFileSync('i18n/overrides.json', 'utf8')));
             _.each(i18n.languages(), function (Lang) {
+                if (!(Lang in languageNames)) fail('Unknown language: ' + Lang);
                 var lang = Lang.toLowerCase().replace(/_/g, '-');
                 fs.writeFileSync(path.join(dest, 'i18n',
                         'open-xchange-appsuite-l10n-' + lang + '.properties'),
@@ -668,11 +781,18 @@ task("dist", [distDest], function () {
                    { cwd: distDest }, dpkgSource);
     }
     function dpkgSource(code) {
-        if (code) return fail();
+        if (code) return fail('tar exited with code ' + code);
+        if (envBoolean('skipDeb')) return done();
         utils.exec(['dpkg-source', '-Zbzip2', '-b', tarName],
                    { cwd: distDest }, done);
     }
-    function done(code) { if (code) return fail(); else complete(); }
+    function done(code) {
+        if (code) {
+            console.warn('dpkg-source exited with code ' + code);
+            console.warn('Debian package is probably not available.');
+        }
+        complete();
+    }
 }, { async: true });
 
 // clean task
