@@ -33,7 +33,7 @@ define('io.ox/calendar/list/perspective',
             vsplit = commons.vsplit(this.main, app),
             left = vsplit.left.addClass('border-right'),
             right = vsplit.right.addClass('default-content-padding calendar-detail-pane').scrollable(),
-            grid = new VGrid(left);
+            grid = new VGrid(left, {settings: settings});
 
         // fix selection's serialize
         grid.selection.serialize = function (obj) {
@@ -76,6 +76,11 @@ define('io.ox/calendar/list/perspective',
                 .fail(_.lfo(drawFail, obj));
         }
 
+        showAppointment.cancel = function () {
+            _.lfo(drawAppointment);
+            _.lfo(drawFail);
+        };
+
         function drawAppointment(data) {
             right.idle().empty().append(viewDetail.draw(data));
         }
@@ -167,9 +172,7 @@ define('io.ox/calendar/list/perspective',
                     var now = _.now();
                     if (!settings.get('showDeclinedAppointments', false)) {
                         data = _.filter(data, function (obj) {
-                            var hash = util.getConfirmations(obj),
-                                conf = hash[ox.user_id] || { status: 1, comment: "" };
-                            return conf.status !== 2;
+                            return util.getConfirmationStatus(obj) !== 2;
                         });
                     }
                     _.map(data, function (obj) {
