@@ -12,15 +12,19 @@
  */
 
 define('io.ox/contacts/api',
-    ['io.ox/core/http',
+    ['io.ox/core/extensions',
+     'io.ox/core/http',
      'io.ox/core/api/factory',
      'io.ox/core/notifications',
      'io.ox/core/cache',
      'settings!io.ox/contacts'
-     ], function (http, apiFactory, notifications, cache, settings) {
+     ], function (ext, http, apiFactory, notifications, cache, settings) {
 
     'use strict';
 
+    // object to store contacts, that have attachments uploading atm
+    var uploadInProgress = {};
+
     // generate basic API
     var api = apiFactory({
         module: 'contacts',
@@ -28,7 +32,8 @@ define('io.ox/contacts/api',
             all: {
                 action: 'all',
                 folder: '6',
-                columns: '20,1,101,500,502',
+                columns: '20,1,101,607',
+                extendColumns: 'io.ox/contacts/api/all',
                 sort: '607', // 607 = magic field
                 order: 'asc',
                 admin: function () {
@@ -37,20 +42,20 @@ define('io.ox/contacts/api',
             },
             list: {
                 action: 'list',
-                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606'
-                    // 524 = internal_userid, 592 = distribution_list,
-                    // 602 = mark_as_distributionlist, 606 = image1_url
+                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607',
+                extendColumns: 'io.ox/contacts/api/list'
             },
             get: {
                 action: 'get'
             },
             search: {
                 action: 'search',
-                columns: '20,1,500,501,502,505,520,555,556,557,569,602,606,524,592',
+                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607',
+                extendColumns: 'io.ox/contacts/api/list',
                 sort: '609', // magic sort field - ignores asc/desc
                 getData: function (query, opt) {
-                    opt |= {};
-                    return {
+                    opt = opt || {};
+                    var data = {
                         display_name: query + '*',
                         first_name: query + '*',
                         last_name: query + '*',
@@ -60,6 +65,9 @@ define('io.ox/contacts/api',
                         orSearch: true,
                         emailAutoComplete: !!opt.emailAutoComplete
                     };
+                    ext.point('io.ox/contacts/api/search')
+                        .invoke('getData', data, query, opt);
+                    return data;
                 }
             }
         }
@@ -72,13 +80,6 @@ define('io.ox/contacts/api',
         }
     }
 
-    function fixDistributionList(data) {
-        // fix last_name for distribution lists (otherwise sorting sucks)
-        if (data.distribution_list && data.distribution_list.length) {
-            data.last_name = data.display_name || '';
-        }
-    }
-
     api.create = function (data, file) {
 
         // TODO: Ask backend for a fix, until that:
@@ -86,28 +87,36 @@ define('io.ox/contacts/api',
         wat(data, 'email2');
         wat(data, 'email3');
 
-        var method, body;
+        var method,
+            attachmentHandlingNeeded = data.tempAttachmentIndicator,
+            opt = {
+                module: 'contacts',
+                data: data,
+                appendColumns: false,
+                fixPost: true
+            };
 
-        fixDistributionList(data);
+        delete data.tempAttachmentIndicator;
 
         if (file) {
-            var body = new FormData();
-            body.append('file', file);
-            body.append('json', JSON.stringify(data));
-            method = 'UPLOAD';
+            if (window.FormData && file instanceof window.File) {
+                method = 'UPLOAD';
+                opt.data = new FormData();
+                opt.data.append('file', file);
+                opt.data.append('json', JSON.stringify(data));
+                opt.params = { action: 'new' };
+            } else {
+                method = 'FORM';
+                opt.form = file;
+                opt.action = 'new';
+            }
         } else {
-            body = data;
             method = 'PUT';
+            opt.params = { action: 'new' };
         }
 
         // go!
-        return http[method]({
-                module: 'contacts',
-                params: { action: 'new' },
-                data: body,
-                appendColumns: false,
-                fixPost: true
-            })
+        return http[method](opt)
             .pipe(function (fresh) {
                 // UPLOAD does not process response data, so ...
                 fresh = fresh.data || fresh;
@@ -120,6 +129,9 @@ define('io.ox/contacts/api',
                     fetchCache.clear()
                 )
                 .pipe(function () {
+                    if (attachmentHandlingNeeded) {
+                        api.addToUploadList(d.folder_id + '.' + d.id);//to make the detailview show the busy animation
+                    }
                     api.trigger('create', { id: d.id, folder: d.folder_id });
                     api.trigger('refresh.all');
                     return d;
@@ -128,11 +140,19 @@ define('io.ox/contacts/api',
     };
 
     api.update =  function (o) {
-
+        var attachmentHandlingNeeded = o.data.tempAttachmentIndicator;
+        delete o.data.tempAttachmentIndicator;
         if (_.isEmpty(o.data)) {
-            return $.when();
+            if (attachmentHandlingNeeded) {
+                return $.when().pipe(function () {
+                    api.addToUploadList(o.folder + '.' + o.id);//to make the detailview show the busy animation
+                    api.trigger('update:' + o.folder + '.' + o.id);
+                    return {folder_id: o.folder, id: o.id};
+                });
+            } else {
+                return $.when();
+            }
         } else {
-            fixDistributionList(o.data);
             // go!
             return http.PUT({
                     module: 'contacts',
@@ -140,7 +160,8 @@ define('io.ox/contacts/api',
                         action: 'update',
                         id: o.id,
                         folder: o.folder,
-                        timestamp: o.timestamp
+                        timestamp: o.timestamp || _.now(),
+                        timezone: 'UTC'
                     },
                     data: o.data,
                     appendColumns: false
@@ -156,9 +177,13 @@ define('io.ox/contacts/api',
                                 fetchCache.clear()
                             )
                             .done(function () {
+                                if (attachmentHandlingNeeded) {
+                                    api.addToUploadList(encodeURIComponent(_.cid(data)));//to make the detailview show the busy animation
+                                }
                                 api.trigger('update:' + encodeURIComponent(_.cid(data)), data);
                                 api.trigger('update', data);
-                                api.trigger('refresh.list');
+                                // trigger refresh.all, since position might have changed
+                                api.trigger('refresh.all');
                             });
                         });
                 });
@@ -167,31 +192,44 @@ define('io.ox/contacts/api',
 
     api.editNewImage = function (o, changes, file) {
 
-        var form = new FormData();
-        form.append('file', file);
-        form.append('json', JSON.stringify(changes));
+        var filter = function (data) {
+            $.when(
+                api.caches.get.clear(),
+                api.caches.list.clear(),
+                fetchCache.clear()
+            ).pipe(function () {
+                api.trigger('refresh.list');
+                api.trigger('edit', { // TODO needs a switch for created by hand or by test
+                    id: o.id,
+                    folder: o.folder_id
+                });
+            });
 
-        return http.UPLOAD({
+            return data;
+        };
+
+        if ('FormData' in window && file instanceof window.File) {
+            var form = new FormData();
+            form.append('file', file);
+            form.append('json', JSON.stringify(changes));
+
+            return http.UPLOAD({
                 module: 'contacts',
                 params: { action: 'update', id: o.id, folder: o.folder_id, timestamp: o.timestamp || _.now() },
                 data: form,
                 fixPost: true
             })
-            .pipe(function (data) {
-                $.when(
-                    api.caches.get.clear(),
-                    api.caches.list.clear(),
-                    fetchCache.clear()
-                ).pipe(function () {
-                    api.trigger('refresh.list');
-                    api.trigger('edit', { // TODO needs a switch for created by hand or by test
-                        id: o.id,
-                        folder: o.folder_id
-                    });
-                });
-
-                return data;
-            });
+            .pipe(filter);
+        } else {
+            return http.FORM({
+                module: 'contacts',
+                action: 'update',
+                form: file,
+                data: changes,
+                params: {id: o.id, folder: o.folder_id, timestamp: o.timestamp || _.now()}
+            })
+            .pipe(filter);
+        }
     };
 
     api.remove =  function (list) {
@@ -200,7 +238,7 @@ define('io.ox/contacts/api',
         // remove
         return http.PUT({
                 module: 'contacts',
-                params: { action: 'delete', timestamp: _.now() },
+                params: { action: 'delete', timestamp: _.now(), timezone: 'UTC' },
                 appendColumns: false,
                 data: _(list).map(function (data) {
                     return { folder: data.folder_id, id: data.id };
@@ -214,11 +252,14 @@ define('io.ox/contacts/api',
                 );
             })
             .done(function () {
+                _(list).map(function (data) {
+                    api.trigger('delete:' + encodeURIComponent(_.cid(data)), data);
+                });
                 api.trigger('refresh.all');
             });
     };
 
-    var autocompleteCache = new cache.SimpleCache('contacts-autocomplete', true);
+    var autocompleteCache = new cache.SimpleCache('contacts-autocomplete', false);
 
     api.on('refresh.all', function () {
         autocompleteCache.clear();
@@ -301,6 +342,10 @@ define('io.ox/contacts/api',
     /** @define {object} simple contact cache */
     var fetchCache = new cache.SimpleCache('contacts-fetching', true);
 
+    api.clearFetchCache = function () {
+        return fetchCache.clear();
+    };
+
    /**
     * get contact redced/filtered contact data; manages caching
     *
@@ -308,7 +353,7 @@ define('io.ox/contacts/api',
     * @return {deferred} deferred returns exactyl one contact object
     */
     api.getByEmailadress = function (address) {
-        address = address || '';
+        address = address || '';
         return fetchCache.get(address).pipe(function (data) {
             if (data !== null) {
                 return data;
@@ -320,7 +365,8 @@ define('io.ox/contacts/api',
                     module: 'contacts',
                     params: {
                         action: 'search',
-                        columns: '20,1,500,501,502,505,520,555,556,557,569,602,606,524,592'
+                        columns: '20,1,500,501,502,505,520,555,556,557,569,602,606,524,592',
+                        timezone: 'UTC'
                     },
                     sort: 609,
                     data: {
@@ -366,6 +412,24 @@ define('io.ox/contacts/api',
         });
     };
 
+    // dirty copy/paste hack until I know hat fetchCache is good for
+    api.getPictureURLSync = function (obj, options) {
+
+        var defaultUrl = ox.base + '/apps/themes/default/dummypicture.png';
+        if (!_.isObject(obj)) { return defaultUrl; }
+
+        // duck checks
+        if (api.looksLikeResource(obj)) {
+            return ox.base + '/apps/themes/default/dummypicture_resource.xpng';
+        } else if (api.looksLikeDistributionList(obj)) {
+            return ox.base + '/apps/themes/default/dummypicture_group.xpng';
+        } else if (obj.image1_url) {
+            return obj.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param(options || {});
+        } else {
+            return defaultUrl;
+        }
+    };
+
    /**
     * gets deferred for fetching picture url
     *
@@ -384,6 +448,7 @@ define('io.ox/contacts/api',
             };
 
         // param empty/null
+        // och bitte klammern nutzen wenn ein ODER dabei ist - ist das jetzt genau so gewollt!?
         if (typeof obj === 'string' && obj === '' || typeof obj === 'object' && obj === null) {
             return deferred.resolve(defaultUrl);
         }
@@ -405,10 +470,9 @@ define('io.ox/contacts/api',
             var id = obj.contact_id || obj.id,
                 folder = obj.folder_id || obj.folder,
                 key = folder + '|' + id;
-            if (id) {
+            if (id && folder) { // need both; folder might be null/0 if from halo view
                 fetchCache.get(key).pipe(function (url) {
-                    if (url)
-                    {
+                    if (url) {
                         deferred.resolve(url);
                     } else {
                         api.get({ id: id, folder: folder }).then(
@@ -548,6 +612,7 @@ define('io.ox/contacts/api',
                     action: action || 'update',
                     id: o.id,
                     folder: o.folder_id || o.folder,
+                    timezone: 'UTC',
                     timestamp: o.timestamp || _.now() // mandatory for 'update'
                 },
                 data: { folder_id: targetFolderId },
@@ -597,7 +662,8 @@ define('io.ox/contacts/api',
             start: now,
             end: now + 604800000, // now + WEEK
             action: 'birthdays',
-            columns: '1,20,500,501,502,503,504,505,511'
+            columns: '1,20,500,501,502,503,504,505,511',
+            timezone: 'UTC'
         }, options || {});
 
         return http.GET({
@@ -615,6 +681,24 @@ define('io.ox/contacts/api',
         return !!obj.mark_as_distributionlist;
     };
 
+    //for busy animation in detail View
+    //ask if this contact has attachments uploading at the moment
+    api.uploadInProgress = function (key) {
+        return uploadInProgress[key] || false;//return true boolean
+    };
+
+    //add contact to the list
+    api.addToUploadList = function (key) {
+        uploadInProgress[key] = true;
+    };
+
+    //remove contact from the list
+    api.removeFromUploadList = function (key) {
+        delete uploadInProgress[key];
+        //trigger refresh
+        api.trigger('update:' + key);
+    };
+
     return api;
 
 });
