@@ -9,7 +9,7 @@
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
-define('io.ox/contacts/widgets/pictureUpload', ['less!io.ox/contacts/widgets/widgets.css'], function () {
+define('io.ox/contacts/widgets/pictureUpload', ['less!io.ox/contacts/widgets/widgets.less'], function () {
 
     "use strict";
 
@@ -25,20 +25,25 @@ define('io.ox/contacts/widgets/pictureUpload', ['less!io.ox/contacts/widgets/wid
                 'change:image1_url': 'displayImageURL'
             },
 
-            openFileChooser: function (e) {
-                this.$el.find('input').trigger('click');
-            },
-
             resetImage: function (e) {
                 e.stopImmediatePropagation();
                 this.model.set("image1", '');
+                this.closeBtn.hide();
                 var imageUrl =  ox.base + '/apps/themes/default/dummypicture.png';
                 this.$el.find('.picture-uploader').css('background-image', 'url(' + imageUrl + ')');
             },
 
-            handleFileSelect: function (e) {
-                var file = e.target.files[0];
-                this.model.set("pictureFile", file);
+            handleFileSelect: function (e, input) {
+                var fileData = {},
+                    $input = $(input);
+                if (this.oldMode) {
+                    if ($input.val()) {
+                        fileData = $input.parent();
+                    }
+                } else {
+                    fileData = input.files[0];
+                }
+                this.model.set("pictureFile", fileData);
             },
 
             displayImageURL: function (e) {
@@ -46,11 +51,16 @@ define('io.ox/contacts/widgets/pictureUpload', ['less!io.ox/contacts/widgets/wid
             },
 
             displayPictureFile: function () {
+                if (this.oldMode) {
+                    return;
+                }
+
                 var self = this,
                     file = this.model.get("pictureFile"),
                     reader = new FileReader();
 
                 reader.onload = function (e) {
+                    self.closeBtn.show();
                     self.$el.find('.picture-uploader').css('background-image', 'url(' + e.target.result + ')');
                 };
 
@@ -58,37 +68,36 @@ define('io.ox/contacts/widgets/pictureUpload', ['less!io.ox/contacts/widgets/wid
             },
 
             render: function () {
-                var self = this;
-                var imageUrl;
+                var self = this,
+                    imageUrl = this.model.get('image1_url'),
+                    hasImage = false;
+                this.oldMode = _.browser.IE < 10;
 
-                if (this.model.get('image1_url')) {
-                    var firstGet = this.model.get('image1_url');
-                    imageUrl = firstGet.replace(/^\/ajax/, ox.apiRoot);
+                if (imageUrl) {
+                    imageUrl = imageUrl.replace(/^\/ajax/, ox.apiRoot);
+                    hasImage = true;
                 } else {
                     imageUrl =  ox.base + '/apps/themes/default/dummypicture.png';
                 }
 
-
                 this.$el.append(
                     $('<div class="picture-uploader thumbnail">').css({
                         backgroundImage: 'url(' + imageUrl + ')',
                         cursor: 'pointer',
                         position: 'relative'
-                    }).on('click', function () {
-                        self.openFileChooser();
                     }).append(
-                        $('<div class="close">').html('&times;').on('click', function (e) {
+                        this.closeBtn = $('<div class="close">').css({zIndex: 2}).html('&times;').on('click', function (e) {
                             self.resetImage(e);
-                        })
+                        })[hasImage ? 'show' : 'hide']()
+                     ),
+                    $('<form>').css({position: 'absolute'}).append(
+                        $('<input type="file" name="file" accepts="image/*">').css({opacity: 0}).css({height: '110px', width: '110px', cursor: 'pointer'})
+                            .on('change', function (e) {
+                                self.handleFileSelect(e, this);
+                            })
                     )
                 );
 
-                this.$el.append(
-                    $('<input type="file" name="picture" accepts="image/*">').css({visibility: 'hidden'})
-                        .on('change', function (e) {
-                            self.handleFileSelect(e);
-                        })
-                );
                 if (this.clear) {
                     this.$el.append($('<div>').css({clear: 'both'}));
                 }
@@ -96,6 +105,5 @@ define('io.ox/contacts/widgets/pictureUpload', ['less!io.ox/contacts/widgets/wid
         }, options);
     }
 
-
     return PictureUpload;
 });
