@@ -11,10 +11,11 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define("io.ox/core/api/factory",
-    ["io.ox/core/http",
-     "io.ox/core/cache",
-     "io.ox/core/event"], function (http, cache, Events) {
+define('io.ox/core/api/factory',
+    ['io.ox/core/http',
+     'io.ox/core/cache',
+     'io.ox/core/event',
+     'io.ox/core/extensions'], function (http, cache, Events, ext) {
 
     "use strict";
 
@@ -50,10 +51,10 @@ define("io.ox/core/api/factory",
             module: "",
             // for all, list, and get
             requests: {
-                all: { action: "all" },
-                list: { action: "list" },
-                get: { action: "get" },
-                search: { action: "search" },
+                all: { action: "all", timezone: 'utc' },
+                list: { action: "list", timezone: 'utc' },
+                get: { action: "get", timezone: 'utc' },
+                search: { action: "search", timezone: 'utc' },
                 remove: { action: "delete" }
             },
             cid: function (o) {
@@ -69,10 +70,18 @@ define("io.ox/core/api/factory",
         // use module as id?
         o.id = o.id || o.module;
 
+        _.each(o.requests, function (request, action) {
+            if (!request.extendColumns) return;
+            request.columns = factory.extendColumns(request.extendColumns,
+                o.module, request.columns);
+            delete request.extendColumns;
+        });
+
         // create 3 caches for all, list, and get requests
         var caches = {
             all: new cache.SimpleCache(o.id + "-all", true),
-            list: new cache.ObjectCache(o.id + "-list", true, o.keyGenerator),
+            //no persistant cache for list, because burst-writes block read (stupid queue implementation)
+            list: new cache.ObjectCache(o.id + "-list", false, o.keyGenerator),
             get: new cache.ObjectCache(o.id + "-get", true, o.keyGenerator)
         };
 
@@ -164,18 +173,23 @@ define("io.ox/core/api/factory",
                     .done(o.done.all || $.noop);
             },
 
-            getList: function (ids, useCache) {
+            getList: function (ids, useCache, options) {
                 // be robust
                 ids = ids ? [].concat(ids) : [];
                 // custom filter
                 if (o.filter) { ids = _(ids).filter(o.filter); }
                 // use cache?
+                options = options || {};
                 useCache = useCache === undefined ? true : !!useCache;
                 // async getter
                 var getter = function () {
+                    var params = _.extend({}, o.requests.list);
+                    if (options.allColumns) {
+                        params.columns = http.getAllColumns(o.module, true);
+                    }
                     return http.fixList(ids, http.PUT({
                         module: o.module,
-                        params: o.requests.list,
+                        params: params,
                         data: http.simplify(ids)
                     }))
                     .pipe(function (data) {
@@ -183,8 +197,9 @@ define("io.ox/core/api/factory",
                     })
                     .pipe(function (data) {
                         // add to cache
-                        // merge with "get" cache
-                        return $.when(caches.list.add(data), caches.get.merge(data)).pipe(function () {
+                        var method = options.allColumns ? 'add' : 'merge';
+                        // merge with or add to "get" cache
+                        return $.when(caches.list.add(data), caches.get[method](data)).pipe(function () {
                             return data;
                         });
                     });
@@ -362,6 +377,11 @@ define("io.ox/core/api/factory",
                 // merge defaults for search
                 var opt = $.extend({}, o.requests.search, options || {}),
                     getData = opt.getData;
+
+                if (o.requests.search.omitFolder) {
+                    opt = _.omit(opt, ['folder', 'omitFolder']);
+                }
+
                 // remove getData functions
                 delete opt.getData;
                 // go!
@@ -400,5 +420,31 @@ define("io.ox/core/api/factory",
 
     factory.reduce = reduce;
 
+    /**
+     * Extends a columns parameter using an extension point.
+     * The columns parameter is a comma-separated list of (usually numeric)
+     * column IDs. The extension point must provide a method 'columns' which
+     * returns an array of field names or column IDs to add.
+     * @param id {string} The name of the extension point.
+     * @param module {string} The module used to map columns to field names.
+     * @param columns {string} The initial value of the columns parameter.
+     * @returns {string} The extended columns parameter.
+     */
+    factory.extendColumns = function (id, module, columns) {
+        var hash = {}, // avoid duplication by using a hash instead of an array
+
+            cols = {}, // a map from field names to column IDs
+            // http has only the reverse version of what we need
+            fields = http.getColumnMapping(module);
+        _.each(fields, function (field, col) { cols[field] = col; });
+
+        _.each(columns.split(','), function (col) { hash[col] = 1; });
+
+        _.chain(ext.point(id).invoke('columns')).flatten(true)
+            .each(function (field) { hash[cols[field] || field] = 1; });
+
+        return _.keys(hash).join();
+    };
+
     return factory;
 });
