@@ -30,18 +30,21 @@ define('io.ox/core/session', ['io.ox/core/http'], function (http) {
         return language in languages ? language : false;
     };
 
-    var set = function (data, language, store) {
-        ox.session = data.session || '';
-        ox.user = data.user; // might have a domain; depends on what the user entered on login
-        ox.user_id = data.user_id || 0;
+    var set = function (data, language) {
+        if ('session' in data) ox.session = data.session || '';
+        if ('user' in data) ox.user = data.user || ''; // might have a domain; depends on what the user entered on login
+        if ('user_id' in data) ox.user_id = data.user_id || 0;
         // if the user has set the language on the login page, use this language instead of server settings lang
         ox.language = language || check(data.locale) || check(getBrowserLanguage()) || 'en_US';
-        return store ? that.store().then(finished, finished) : finished();
-        function finished() { return $.when(data); }
+        $('html').attr('lang', ox.language.split('_')[0]);
+        // should not hide store() request here; made debugging hard
+        ox.trigger("change:session", ox.session);
     };
 
     var that = {
 
+        set: set,
+
         autoLogin: function () {
             var store = false;
             // GET request
@@ -53,27 +56,38 @@ define('io.ox/core/session', ['io.ox/core/http'], function (http) {
                 timeout: TIMEOUTS.AUTOLOGIN,
                 params: {
                     action: 'autologin',
-                    client: that.client()
+                    client: that.client(),
+                    version: that.version()
                 }
             })
             // If autologin fails, try the token login
-            .then(null, function () {
-                if (!_.url.hash('serverToken')) return;
-                return http.POST({
-                    module: 'login',
-                    jsessionid: _.url.hash('jsessionid'),
-                    appendColumns: false,
-                    appendSession: false,
-                    processResponse: false,
-                    timeout: TIMEOUTS.AUTOLOGIN,
-                    params: {
-                        action: 'tokens',
-                        client: that.client(),
-                        serverToken: _.url.hash('serverToken'),
-                        clientToken: _.url.hash('clientToken')
-                    }
-                }).then(function (response) { return response.data; });
-            })
+            .then(
+                function (data) {
+                    ox.secretCookie = true;
+                    return data;
+                },
+                function () {
+                    if (!_.url.hash('serverToken')) return;
+                    return http.POST({
+                        module: 'login',
+                        jsessionid: _.url.hash('jsessionid'),
+                        appendColumns: false,
+                        appendSession: false,
+                        processResponse: false,
+                        timeout: TIMEOUTS.AUTOLOGIN,
+                        params: {
+                            action: 'tokens',
+                            client: that.client(),
+                            version: that.version(),
+                            serverToken: _.url.hash('serverToken'),
+                            clientToken: _.url.hash('clientToken')
+                        }
+                    })
+                    .then(function (response) {
+                        return response.data;
+                    });
+                }
+            )
             .done(function () {
                 store = _.url.hash('store');
                 _.url.hash({
@@ -83,8 +97,9 @@ define('io.ox/core/session', ['io.ox/core/http'], function (http) {
                     store: null
                 });
             })
-            .then(function (data) {
-                return set(data, undefined, store);
+            .done(function (data) {
+                set(data);
+                // no "store" request here; just auto-login
             });
         },
 
@@ -128,13 +143,19 @@ define('io.ox/core/session', ['io.ox/core/http'], function (http) {
                                 password: password,
                                 language: language,
                                 client: that.client(),
+                                version: that.version(),
                                 timeout: TIMEOUTS.LOGIN,
                                 multiple: JSON.stringify(multiple)
                             }
                         })
                         .done(function (data) {
                             // store session
-                            set(data, language, store).done(def.resolve(data));
+                            set(data, language);
+                            if (store) {
+                                that.store().done(function () { def.resolve(data); });
+                            } else {
+                                def.resolve(data);
+                            }
                         })
                         .fail(def.reject);
                     }
@@ -143,21 +164,23 @@ define('io.ox/core/session', ['io.ox/core/http'], function (http) {
                     set({ session: 'offline', user: username }, language);
                     def.resolve({ session: ox.session, user: ox.user });
                 }
-
                 return def;
             };
         }()),
 
         store: function () {
-            // GET request
-            return http.GET({
+            var def = $.Deferred();
+            // change from GET to POST request, cause firefox has a
+            // problem otherwise if caches are empty
+            http.POST({
                 module: 'login',
                 appendColumns: false,
                 processResponse: false,
-                params: {
-                    action: 'store'
-                }
-            });
+                params: { action: 'store' }
+            })
+            // makes store() always successful (should never block)
+            .always(def.resolve);
+            return def;
         },
 
         logout: function () {
@@ -178,6 +201,11 @@ define('io.ox/core/session', ['io.ox/core/http'], function (http) {
 
         client: function () {
             return 'open-xchange-appsuite';
+        },
+
+        version: function () {
+            // need to work with ox.version since we don't have the server config for auto-login
+            return String(ox.version).split('.').slice(0, 3).join('.');
         }
     };
 
