@@ -22,8 +22,9 @@ define('io.ox/core/tk/folderviews',
      'io.ox/core/notifications',
      'io.ox/core/http',
      'io.ox/core/cache',
+     'io.ox/core/capabilities',
      'gettext!io.ox/core'
-    ], function (Selection, api, account, userAPI, ext, Events, config, notifications, http, cache, gt) {
+    ], function (Selection, api, account, userAPI, ext, Events, config, notifications, http, cache, capabilities, gt) {
 
     'use strict';
 
@@ -32,7 +33,9 @@ define('io.ox/core/tk/folderviews',
 
         tmplFolder = $('<div class="folder selectable">').append('<div class="folder-row">'),
         tmplSub = $('<div>').addClass('subfolders').hide(),
-
+        MOBILEFOLDERPADDING = 15,
+        DESKTOPFOLDERPADDING = 30,
+        SUBFOLDERPADDING = _.device('small') ? MOBILEFOLDERPADDING : DESKTOPFOLDERPADDING,
         refreshHash = {},
 
         TRUE = function () { return true; };
@@ -47,6 +50,8 @@ define('io.ox/core/tk/folderviews',
             children = null,
             painted = false,
             detached = true,
+            loading = null,
+            wasOpen = false,
             open,
             self = this,
             data = {},
@@ -72,10 +77,18 @@ define('io.ox/core/tk/folderviews',
             },
 
             drawChildren = function (reload, method) {
+
+                if (loading) return $.Deferred().resolve([]);
+
+                // remove potential fail messages from previous refreshes
+                nodes.sub.find('.io-ox-fail').parent().remove();
+
                 // be busy
-                nodes.sub.busy().show();
+                if (children === null || isOpen()) nodes.sub.busy().show();
+
                 // load
-                return self.loadChildren(reload)
+                return (
+                    loading = self.loadChildren(reload)
                     // next pipe() makes it slow for debugging
                     // .pipe(function (children) {
                     //    var def = $.Deferred();
@@ -90,20 +103,29 @@ define('io.ox/core/tk/folderviews',
                             $.fail(gt('Couldn\'t load subfolders.'), function () {
                                 drawChildren(reload, method);
                             })
+                            .attr('data-folder-id', id)
                         );
                     })
-                    .pipe(function (children) {
+                    .then(function (children) {
                         // tricky one liner: we invoke 'paint' for all child nodes.
-                        // invoke returns a nice array of all returns values which are deferred objects.
+                        // invoke returns a nice array of all return values which all are deferred objects.
                         // we use this array to feed $.when(). Thus, we get a proper combined deferred object
                         // that will be resolved once all child nodes are resolved.
                         if (!children || children.length === 0) {
                             nodes.sub.idle().hide(); // Robustness. Sometimes the folder interface seems unsure about subfolders.
                             hideArrow();
                             return $.when();
+                        } else {
+                            wasOpen = true;
                         }
                         return $.when.apply(null, _(children).invoke(method, nodes.sub));
-                    });
+                    })
+                    .always(_.defer(function () {
+                        // need to use defer here, otherwise tree selection gets broken
+                        // with second repaint (visually ok but lacks addToIndex calls)
+                        loading = null;
+                    }))
+                );
             },
 
             paintChildren = function () {
@@ -111,7 +133,12 @@ define('io.ox/core/tk/folderviews',
             },
 
             repaintChildren = function () {
-                return drawChildren(true, 'repaint');
+                return drawChildren(true, 'repaint').done(function () {
+                    // fix changed orders by re-appending all children
+                    _(children).each(function (child) {
+                        child.append(true);
+                    });
+                });
             },
 
             updateArrow = function () {
@@ -212,86 +239,70 @@ define('io.ox/core/tk/folderviews',
             });
         };
 
+        this.data = function (obj) {
+            if (!arguments.length) {
+                return data;
+            } else {
+                data = obj;
+                return this;
+            }
+        };
+
         // load sub folders - creates instances of TreeNode - does not yet paint them
         this.loadChildren = function (reload) {
+
             var hash = {}, needsRefresh;
+
             if (children === null || reload === true) {
                 // build hash?
                 if (children !== null && reload === true) {
                     _(children).each(function (node) {
-                        hash[node.id] = node.detach();
+                        hash[node.id] = node;
                     });
                 }
-                // check cache
-                return api.caches.subFolderCache.get(id).pipe(function (data) {
-                    var wasCached = data !== null,
-                        needsRefresh = wasCached && refreshHash[id] === undefined;
-                    // get sub folders
-                    return api.getSubFolders({ folder: id, all: all, storage: storage })
-                        .done(function (list) {
-                            // needs refresh?
-                            if (needsRefresh) {
-                                _.defer(function () {
-                                    // get fresh data
-                                    api.getSubFolders({ folder: id, cache: false }).done(function (freshList) {
-                                        // compare
-                                        if (!_.isEqual(list, freshList)) {
-                                            self.repaint();
-                                        }
-                                        refreshHash[id] = false;
-                                    });
-                                });
+                // we assume that folder API takes care of clearing caches for periodic refreshes
+                // get sub folders
+                return api.getSubFolders({ folder: id, all: all, storage: storage }).then(function (data) {
+                    // create new children array
+                    children = _.chain(data)
+                        .filter(function (folder) {
+                            // ignore system folders without sub folders, e.g. 'Shared folders'
+                            return (folder.module !== 'system' || folder.subfolders) && filter(folder);
+                        })
+                        .map(function (folder) {
+                            if (hash[folder.id] !== undefined) {
+                                // reuse but update data
+                                var node = hash[folder.id].data(folder);
+                                delete hash[folder.id];
+                                return node;
+                            } else {
+                                // new node
+                                return new TreeNode(tree, folder.id, nodes.sub, skip() ? level : level + 1, checkbox, all, storage);
                             }
                         })
-                        .pipe(function (data) {
-                            // create new children array
-                            children = _.chain(data)
-                                .filter(function (folder) {
-                                    // ignore system folders without sub folders, e.g. 'Shared folders'
-                                    return (folder.module !== 'system' || folder.subfolders) && filter(folder);
-                                })
-                                .map(function (folder) {
-                                    if (reload && hash[folder.id] !== undefined) {
-                                        // reuse
-                                        var node = hash[folder.id];
-                                        delete hash[folder.id];
-                                        return node;
-                                    } else {
-                                        // new node
-                                        return new TreeNode(tree, folder.id, nodes.sub, skip() ? level : level + 1, checkbox, all, storage);
-                                    }
-                                })
-                                .value();
-                            // destroy deprecated tree nodes
-                            _(hash).each(function (child) {
-                                child.destroy();
-                            });
-                            hash = null;
-                            return children;
-                        });
+                        .value();
+                    // destroy remaining and thus deprecated tree nodes
+                    _(hash).each(function (child) {
+                        child.destroy();
+                    });
+                    hash = null;
+                    return children;
                 });
             } else {
                 return $.Deferred().resolve(children);
             }
         };
 
-        this.append = function () {
-            if (detached) {
+        this.append = function (force) {
+            if (detached || force) {
                 container.append(nodes.folder, nodes.sub);
                 detached = false;
             }
         };
 
-        this.detach = function () {
-            detached = true;
-            nodes.folder.detach();
-            nodes.sub.detach();
-            return this;
-        };
-
         this.destroy = function () {
             // remove from parent node
-            var node = tree.getNode(data.folder_id);
+            var node = data && tree.getNode(data.folder_id);
             if (node) {
                 node.removeChild(this);
             }
@@ -311,20 +322,17 @@ define('io.ox/core/tk/folderviews',
 
         this.repaint = function () {
             if (painted) {
-                // adD?
+                // add?
                 self.append();
                 // get folder
-                return this.reload().pipe(function (promise) {
-                    // get data
-                    data = promise;
-                    // customize, re-add to index, update arrow
-                    self.customize();
+                return this.reload().pipe(function () {
+                    // reload resets promise, calls customize & updateArrow
                     if (nodes.folder.hasClass('selectable')) {
                         tree.selection.addToIndex(data.id);
                     }
-                    updateArrow();
-                    // draw children
-                    if (isOpen()) {
+                    // draw children? check wasOpen cause we might have to draw
+                    // newly added subfolders (which won't appear for closed folders)
+                    if (wasOpen || isOpen()) {
                         return repaintChildren();
                     } else {
                         return $.when();
@@ -341,10 +349,10 @@ define('io.ox/core/tk/folderviews',
         // paint tree node - loads and paints sub folder if open
         this.paint = function () {
 
-            nodes.folder = tmplFolder.clone().on('dblclick click', '.folder-arrow, .folder-label', toggleState);
+            nodes.folder = tmplFolder.clone().on('dblclick mousedown', '.folder-arrow, .folder-label', toggleState);
 
             if (level > 0) {
-                nodes.folder.css('paddingLeft', (0 + level * 30) + 'px');
+                nodes.folder.css('paddingLeft', (0 + level * SUBFOLDERPADDING) + 'px');
             }
 
             nodes.sub = tmplSub.clone();
@@ -378,7 +386,7 @@ define('io.ox/core/tk/folderviews',
                 var def = isOpen() ? paintChildren() : $.when();
                 updateArrow();
                 // add to DOM
-                if (checkbox && (data.own_rights & 0x3f80)) {
+                if (checkbox && ((data.own_rights & 0x3f80 /* read access */) || data.subscribed /* to get rid of folder */)) {
                     nodes.folder.find('.folder-row').append(nodes.arrow, nodes.label, nodes.counter, nodes.subscriber);
                 } else {
                     nodes.folder.find('.folder-row').append(nodes.arrow, nodes.label, nodes.counter);
@@ -434,7 +442,7 @@ define('io.ox/core/tk/folderviews',
             .append(this.container = $('<div class="folder-root">'));
 
         // selection
-        Selection.extend(this, container) // not this.container!
+        Selection.extend(this, container, { dropzone: true, dropType: 'folder' }) // not this.container!
             .setMultiple(false)
             .setSerializer(function (obj) {
                 return String(obj.id);
@@ -502,7 +510,7 @@ define('io.ox/core/tk/folderviews',
 
         function fnKeyPress(e) {
             if (e.which === 13) {
-                e.data.popup.process('add');
+                e.data.popup.invoke(e.data.action);
             }
         }
 
@@ -515,8 +523,6 @@ define('io.ox/core/tk/folderviews',
         this.addProcess = function (folder, title, opt) {
             var self = this,
             opt = opt || {};
-            // be responsive
-            this.busy();
             // call API
             return api.create({
                 folder: folder,
@@ -524,11 +530,6 @@ define('io.ox/core/tk/folderviews',
                     title: $.trim(title) || gt('New folder'),
                     module: opt.module
                 }
-            })
-            .done(function (data) {
-                self.idle().repaint().done(function () {
-                    self.select(data.id);
-                });
             });
         };
 
@@ -544,32 +545,34 @@ define('io.ox/core/tk/folderviews',
             if (folder) {
                 require(['io.ox/core/tk/dialogs'], function (dialogs) {
                     new dialogs.ModalDialog({
-                        width: 400,
-                        easyOut: true
+                        async: true,
+                        easyOut: true,
+                        width: 400
                     })
                     .header(
-                        $('<h4>').text(gt('Add new subfolder'))
+                        $('<h4>').text(folder === '1' ? gt('Add new folder') : gt('Add new subfolder'))
                     )
                     .build(function () {
                         this.getContentNode().append(
                             $('<div class="row-fluid">').append(
-                                api.getBreadcrumb(folder, { subfolders: false }),
+                                folder !== '1' ? api.getBreadcrumb(folder, { subfolders: false }) : [],
                                 $('<input>', { type: 'text' })
                                 .attr('placeholder', gt('Folder name'))
                                 .addClass('span12')
-                                .on('keypress', { popup: this }, fnKeyPress)
+                                .on('keypress', { popup: this, action: 'add' }, fnKeyPress)
                             )
                         );
                     })
-                    .addButton('cancel', gt('Cancel'))
                     .addPrimaryButton('add', gt('Add folder'))
+                    .addButton('cancel', gt('Cancel'))
+                    .on('add', function () {
+                        var popup = this;
+                        self.addProcess(folder, this.getContentNode().find('input').val(), opt).always(function () {
+                            popup.close();
+                        });
+                    })
                     .show(function () {
                         this.find('input').focus();
-                    })
-                    .done(function (action) {
-                        if (action === 'add') {
-                            self.addProcess(folder, this.find('input').val(), opt);
-                        }
                     });
                 });
             }
@@ -602,7 +605,7 @@ define('io.ox/core/tk/folderviews',
         };
 
         this.renameProcess = function (folder, changes) {
-            api.update({ folder: folder, changes: changes });
+            return api.update({ folder: folder, changes: changes });
         };
 
         this.rename = function (folder) {
@@ -619,8 +622,9 @@ define('io.ox/core/tk/folderviews',
                         return;
                     }
                     new dialogs.ModalDialog({
-                        width: 400,
-                        easyOut: true
+                        async: true,
+                        easyOut: true,
+                        width: 400
                     })
                     .header(
                         $('<h4>').text(gt('Rename folder'))
@@ -633,25 +637,25 @@ define('io.ox/core/tk/folderviews',
                                 .val(folder.title)
                                 .attr('placeholder', gt('Folder name'))
                                 .addClass('span12')
-                                .on('keypress', { popup: this }, fnKeyPress)
+                                .on('keypress', { popup: this, action: 'rename' }, fnKeyPress)
                             )
                         );
                     })
+                    .addPrimaryButton('rename', gt('Rename'))
                     .addButton('cancel', gt('Cancel'))
-                    .addPrimaryButton('add', gt('Rename'))
+                    .on('rename', function () {
+                        self.renameProcess(folder.id, { title: this.getContentNode().find('input').val() })
+                            .always(this.close);
+                    })
                     .show(function () {
                         this.find('input').focus();
-                    })
-                    .done(function (action) {
-                        if (action === 'add') {
-                            self.renameProcess(folder.id, { title: this.find('input').val() });
-                        }
                     });
                 });
             }
         };
 
         this.subscribe = function (data) {
+
             var name = data.app.getName(),
                 POINT = name + '/folderview',
                 folderCache = new cache.SimpleCache('folder-all', false),
@@ -663,7 +667,6 @@ define('io.ox/core/tk/folderviews',
 
             var options;
             _(ext.point(POINT + '/options').all()).each(function (obj) {
-
                 options = _.extend(obj, options || {});
             });
 
@@ -676,8 +679,6 @@ define('io.ox/core/tk/folderviews',
                 storage: storage
             });
 
-            tree.paint();
-
             require(['io.ox/core/tk/dialogs'], function (dialogs) {
                 var pane = new dialogs.ModalDialog({
                     width: 500,
@@ -690,20 +691,18 @@ define('io.ox/core/tk/folderviews',
                     $('<h4>').text(gt('Subscribe IMAP folders'))
                 )
                 .build(function () {
-                    this.getContentNode().append(
-                        container
-                    );
+                    this.getContentNode().append(container);
                 })
-                .addButton('cancel', gt('Cancel'))
                 .addPrimaryButton('save', gt('Save'))
+                .addButton('cancel', gt('Cancel'))
                 .show(function () {
-                }).done(function (action) {
-
+                    tree.paint();
+                })
+                .done(function (action) {
                     if (action === 'save') {
                         _(changesArray).each(function (change) {
                             api.update(change, storage);
                         });
-
                         tree.destroy();
                         tree = pane = null;
                     }
@@ -711,19 +710,16 @@ define('io.ox/core/tk/folderviews',
                         tree.destroy();
                         tree = pane = null;
                     }
-                }
-                );
+                });
 
                 tree.container.on('change', 'input', function () {
                     var folder = $(this).val(),
                         checkboxStatus = $(this).is(':checked'),
-                        changes = {subscribed: checkboxStatus},
+                        changes = { subscribed: checkboxStatus },
                         tobBePushed = { folder: folder, changes: changes};
                     changesArray.push(tobBePushed);
                 });
-
             });
-
         };
     }
 
@@ -864,6 +860,45 @@ define('io.ox/core/tk/folderviews',
         }
     });
 
+    function openPubSubSettings(e) {
+        var options = { id: 'io.ox/core/pubsub', folder: e.data.folder.id, data: e.data.folder };
+        ox.launch('io.ox/settings/main', options).done(function () {
+            this.setSettingsPane(options);
+        });
+    }
+
+    ext.point('io.ox/foldertree/folder').extend({
+        index: 200,
+        id: 'published',
+        customize: function (data) {
+            if (capabilities.has('publication') && api.is('published|subscribed', data)) {
+                this.find('.folder-label').append(
+                    $('<i class="icon-cloud-download folder-pubsub">').attr('title', gt('This folder has publications and/or subscriptions'))
+                    .on('click', { folder: data }, openPubSubSettings)
+                );
+            }
+        }
+    });
+
+    function openPermissions(e) {
+        require(['io.ox/core/permissions/permissions'], function (controller) {
+            controller.show(e.data.folder);
+        });
+    }
+
+    ext.point('io.ox/foldertree/folder').extend({
+        index: 300,
+        id: 'shared',
+        customize: function (data) {
+            if (api.is('unlocked', data)) {
+                this.find('.folder-label').append(
+                    $('<i class="icon-unlock folder-pubsub">').attr('title', gt('You share this folder with other users'))
+                    .on('click', { folder: data.id }, openPermissions)
+                );
+            }
+        }
+    });
+
     var sections = { 'private': gt('Private'), 'public': gt('Public'), 'shared': gt('Shared') };
 
     function FolderList(container, opt) {
@@ -876,7 +911,6 @@ define('io.ox/core/tk/folderviews',
 
             var folder = tmplFolder.clone()
                 .append(
-                    $('<img>', { src: '', alt: '' }).addClass('folder-icon'),
                     $('<span>').addClass('folder-label')
                 )
                 .attr('data-obj-id', data.id);
@@ -951,12 +985,19 @@ define('io.ox/core/tk/folderviews',
             return paint({ cache: false });
         };
 
-        this.removeNode = this.repaintNode = this.internal.repaint;
+        // removeNode should not trigger repaint; just be busy
+        this.removeNode = function () {
+            this.busy();
+        };
 
         this.select = function (data) {
             this.selection.set(data);
             return $.when();
         };
+
+        api.on('delete', function () {
+            self.repaint();
+        });
     }
 
     return {
