@@ -13,9 +13,10 @@
 
 define('io.ox/mail/accounts/view-form',
     ['io.ox/core/tk/view',
+     'io.ox/core/notifications',
      'text!io.ox/mail/accounts/account_detail.html',
      'gettext!io.ox/settings/settings'
-    ], function (View, tmpl, gt) {
+    ], function (View, notifications, tmpl, gt) {
 
     'use strict';
 
@@ -42,7 +43,13 @@ define('io.ox/mail/accounts/view-form',
             SERVER_OUT_PORT: gt('Server Port:'),
             LOGIN_AND_PASS: gt('Use Login and Password'),
             LOGIN_OUT: gt('Login'),
-            PASSWORD_OUT: gt('Password')
+            PASSWORD_OUT: gt('Password'),
+            TITLE_FOLDER_SETTINGS: gt('Folder Settings'),
+            FOLDER_SEND: gt('Send folder'),
+            FOLDER_TRASH: gt('Trash folder'),
+            FOLDER_DRAFTS: gt('Drafts folder'),
+            FOLDER_SPAM: gt('Spam folder'),
+            SPAN_SELECT_FOLDER: gt('Select')
         },
 
         optionsServerType = _(['imap', 'pop3']).map(gt.noI18n),
@@ -56,55 +63,55 @@ define('io.ox/mail/accounts/view-form',
                 // create template
                 this.template = doT.template(tmpl);
                 this._modelBinder = new Backbone.ModelBinder();
-                
+
                 //check if login and mailaddress are synced
                 this.inSync = false;
 
-                Backbone.Validation.bind(this, {selector: 'data-property'});
+                Backbone.Validation.bind(this, {selector: 'data-property', forceUpdate: true});//forceUpdate needed otherwise model is always valid even if inputfields contain wrong values
             },
             render: function () {
                 var self = this;
-                window.account = self.model;
+                window.account = self.model; //FIXME: WTF?
                 self.$el.empty().append(self.template({
                     strings: staticStrings,
                     optionsServer: optionsServerType,
                     optionsRefreshRate: optionsRefreshRatePop
                 }));
-                var pop3node = self.$el.find('[data-property="pop3_refresh_rate"]').parentsUntil('.form-horizontal', '.control-group').first();
-                
+                var pop3nodes = self.$el.find('.control-group.pop3');
+
                 var defaultBindings = Backbone.ModelBinder.createDefaultBindings(self.el, 'data-property');
                 self._modelBinder.bind(self.model, self.el, defaultBindings);
                 //check if pop3 refresh rate needs to be displayed
-                if (self.model.get('mail_protocol') === 'imap') {
-                    pop3node.hide();
+                if (self.model.get('mail_protocol') !== 'pop3') {
+                    pop3nodes.hide();
                 }
-                
+
                 function syncLogin(model, value) {
-                        model.set('login', value);
-                    }
-                
+                    model.set('login', value);
+                }
+
                 if (self.model.get('id') !== 0) {//check for primary account
-                    
+
                     //refreshrate field needs to be toggled
                     self.model.on('change:mail_protocol', function (model, value) {
-                        if (value === 'imap') {
-                            pop3node.hide();
+                        if (value !== 'pop3') {
+                            pop3nodes.hide();
                         } else {
-                            pop3node.show();
+                            pop3nodes.show();
                         }
                     });
-                    
+
                     //login for server should be email-address by default;
                     if (self.model.get('login') === undefined) {
                         self.model.set('login', self.model.get('primary_address'));
                     }
-                    
+
                     //if login and mailadress are the same change login if mailadress changes
                     if (self.model.get('primary_address') === self.model.get('login') && !self.inSync) {
                         self.model.on('change:primary_address', syncLogin);
                         self.inSync = true;
                     }
-                    
+
                     //react to loginchange
                     self.model.on('change:login', function (model, value) {
                         if (value === model.get('primary_address')) {
@@ -119,18 +126,20 @@ define('io.ox/mail/accounts/view-form',
                     });
                 } else {//primary account does not allow editing besides display name and unified mail
                     self.$el.find('input, select').not('#personal, [data-property="unified_inbox_enabled"]').attr('disabled', 'disabled');
+                    self.$el.find('button.btn.folderselect').hide();
                 }
-                
+
                 return self;
             },
             events: {
-                'click .save': 'onSave'
+                'save': 'onSave',
+                'click .folderselect': 'onFolderSelect'
             },
             onSave: function () {
-                var self = this,
-                    deferedSave = $.Deferred();
-                this.model.save(false, deferedSave);
-                deferedSave.done(function (data) {
+                var self = this;
+
+                this.model.save()
+                .done(function (data) {
                     self.dialog.close();
                     if (self.collection) {
                         self.collection.add([data]);
@@ -138,7 +147,54 @@ define('io.ox/mail/accounts/view-form',
                     if (self.model.isNew()) {
                         self.succes();
                     }
+                })
+                .fail(function (data) {
+                    if (data.code === "ACC-0004" && data.error_params[0].substring(8, 13) === 'login') {//string comparison is ugly, maybe backend has a translated version of this
+                        notifications.yell('error', gt('Login must not be empty.'));
+                    } else if (data.code === "SVL-0002") {
+                        notifications.yell('error',
+                                           //#. %1$s the missing request parameter
+                                           //#, c-format
+                                           gt("Please enter the following data: %1$s", _.noI18n(data.error_params[0])));
+                    } else {
+                        notifications.yell('error', _.noI18n(data.error));
+                    }
                 });
+            },
+
+            onFolderSelect: function (e) {
+                var self = this;
+                if (self.model.get('id') !== 0) {
+                    var property = $(e.currentTarget).prev().attr('data-property'),
+                        id = self.model.get(property),
+                        accountName = self.model.get('name');
+                    require(["io.ox/core/tk/dialogs", "io.ox/core/tk/folderviews"], function (dialogs, views) {
+
+                        var label = gt('Select folder'),
+                            dialog = new dialogs.ModalDialog({ easyOut: true })
+                            .header($('<h3>').text(label))
+                            .addPrimaryButton("select", label)
+                            .addButton("cancel", gt("Cancel"));
+                        dialog.getBody().css({ height: '250px' });
+                        var tree = new views.FolderTree(dialog.getBody(), {
+                                type: 'mail',
+                                rootFolderId: 'default' + self.model.get('id')
+                            });
+                        dialog.show(function () {
+                            tree.paint().done(function () {
+                                tree.select(id);
+                            });
+                        })
+                        .done(function (action) {
+                            if (action === 'select') {
+                                var target = _(tree.selection.get()).first();
+                                self.model.set(property, target);
+                            }
+                            tree.destroy();
+                            tree = dialog = null;
+                        });
+                    });
+                }
             }
         });
 
