@@ -14,9 +14,10 @@
 
 define('io.ox/mail/util',
     ['io.ox/core/extensions',
-     'io.ox/core/config',
      'io.ox/core/date',
-     'gettext!io.ox/core'], function (ext, config, date, gt) {
+     'io.ox/core/api/account',
+     'settings!io.ox/mail',
+     'gettext!io.ox/core'], function (ext, date, accountAPI, settings, gt) {
 
     'use strict';
 
@@ -36,21 +37,22 @@ define('io.ox/mail/util',
             });
         },
 
-        getDateFormated = function (timestamp, fulldate) {
-            var now = new date.Local(),
+        getDateFormated = function (timestamp, options) {
+            var opt = $.extend({fulldate: true, filtertoday: true}, options || {}),
+                now = new date.Local(),
                 d = new date.Local(date.Local.utc(timestamp)),
                 timestr = function () {
                     return d.format(date.TIME);
                 },
                 datestr = function () {
-                    return d.format(date.DATE) + (fulldate ? ' ' + timestr() : '');
+                    return d.format(date.DATE) + (opt.fulldate ? ' ' + timestr() : '');
                 },
                 isSameDay = function () {
                     return d.getDate() === now.getDate() &&
                         d.getMonth() === now.getMonth() &&
                         d.getYear() === now.getYear();
                 };
-            return isSameDay() ? timestr() : datestr();
+            return isSameDay() && opt.filtertoday ? timestr() : datestr();
         },
 
 
@@ -68,12 +70,15 @@ define('io.ox/mail/util',
         // mail addresses hash
         addresses = {};
 
-    _(config.get('mail.addresses', [])).each(function (address) {
-        addresses[address.toLowerCase()] = true;
+    accountAPI.getAllSenderAddresses().done(function (sendAddresses) {
+        _(sendAddresses).chain().pluck(1).each(function (address) {
+            addresses[address.toLowerCase()] = true;
+        });
     });
 
 
     that = {
+
         parseRecipient: function (s) {
             var recipient = $.trim(s), match, name, email;
             if ((match = recipient.match(rRecipient)) !== null) {
@@ -208,7 +213,7 @@ define('io.ox/mail/util',
                 address = args[0][1];
             }
             name = _.isString(name) ? name.replace(rDisplayNameCleanup, '') : '';
-            address = $.trim(address || '').toLowerCase();
+            address = $.trim(address || '').toLowerCase();
             return name === '' ? address : '"' + name + '" <' + address + '>';
         },
 
@@ -217,16 +222,30 @@ define('io.ox/mail/util',
         },
 
         getPriority: function (data) {
-            var i = '<i class="icon-star"></i>';
-            return data.priority < 3 ? $('<span>').append(_.noI18n('\u00A0'), i, i, i) : $();
+            // normal?
+            if (data.priority === 3) return $();
+            var i = '<i class="icon-star"/>',
+                stars = $('<span>').append(_.noI18n('\u00A0'), i, i, i);
+            return stars.addClass(data.priority < 3 ? 'high' : 'low');
+        },
+
+        getAccountName: function (data) {
+            // primary account?
+            var id = window.unescape(data.id);
+            return (/^default0/).test(id) ? gt('Primary account') : (data.account_name || 'N/A');
         },
 
         getTime: function (timestamp) {
-            return getDateFormated(timestamp, false);
+            return getDateFormated(timestamp, { fulldate: false });
         },
 
-        getDateTime: function (timestamp) {
-            return getDateFormated(timestamp, true);
+        getDateTime: function (timestamp, options) {
+            return getDateFormated(timestamp, options);
+        },
+
+        getFullDate: function (timestamp) {
+            var t = new date.Local(date.Local.utc(timestamp));
+            return t.format(date.DATE_TIME);
         },
 
         getSmartTime: function (timestamp) {
@@ -292,7 +311,7 @@ define('io.ox/mail/util',
         },
 
         getInitialDefaultSender: function () {
-            var mailArray = _(config.get('modules.mail.sendaddress', []));
+            var mailArray = _(settings.get('defaultSendAddress', []));
             return mailArray._wrapped[0];
         },
 
