@@ -22,9 +22,10 @@ define('io.ox/mail/view-detail',
      'io.ox/core/api/account',
      'settings!io.ox/mail',
      'gettext!io.ox/mail',
+     'io.ox/core/api/folder',
      'io.ox/mail/actions',
-     'less!io.ox/mail/style.css'
-    ], function (ext, links, util, api, config, http, account, settings, gt) {
+     'less!io.ox/mail/style.less'
+    ], function (ext, links, util, api, config, http, account, settings, gt, folder) {
 
     'use strict';
 
@@ -73,8 +74,8 @@ define('io.ox/mail/view-detail',
 
     var regHTML = /^text\/html$/i,
         regImage = /^image\/(jpe?g|png|gif|bmp)$/i,
-        regFolder = /^(\s*)(http[^#]+#m=infostore&f=\d+)(\s*)$/i,
-        regDocument = /^(\s*)(http[^#]+#m=infostore&f=\d+&i=\d+)(\s*)$/i,
+        regFolder = /^(\s*)(http[^#]+#m=infostore&f=(\d+))(\s*)$/i,
+        regDocument = /^(\s*)(http[^#]+#m=infostore&f=(\d+)&i=(\d+))(\s*)$/i,
         regDocumentAlt = /^(\s*)(http[^#]+#!&?app=io\.ox\/files(?:&perspective=list)?&folder=(\d+)&id=([\d\.]+))(\s*)$/i,
         regLink = /^(.*)(https?:\/\/\S+)(\s.*)?$/i,
         regMail = /([^\s<;\(\)\[\]]+@([a-z0-9äöüß\-]+\.)+[a-z]{2,})/i,
@@ -83,20 +84,51 @@ define('io.ox/mail/view-detail',
         regMailComplexReplace = /(&quot;([^&]+)&quot;|"([^"]+)"|'([^']+)')(\s|<br>)+&lt;([^@]+@[^&]+)&gt;/g, /* "name" <address> */
         regImageSrc = /(<img[^>]+src=")\/ajax/g;
 
+    var insertEmoticons = (function () {
+
+        var emotes = {
+            ':-)': 'smile',
+            ':)': 'smile',
+            ';-)': 'wink',
+            ';)': 'wink',
+            ':-D': 'laugh',
+            ':D': 'laugh',
+            ':-|': 'neutral',
+            ':|': 'neutral',
+            ':-(': 'sad',
+            ':(': 'sad'
+        };
+
+        var regex = /(&quot)?([:;]-?[(|)D])/g;
+
+        return function (text) {
+            if (!settings.get('displayEmoticons')) return text;
+            return text.replace(regex, function (all, quot, match) {
+                // if we hit &quot;-) we just return
+                if (quot) return all;
+                // otherwise find emote
+                var emote = emotes[match];
+                return !emote ? match : '<i class="emote ' + emote + '"></i>';
+            });
+        };
+    }());
+
     var beautifyText = function (text) {
 
         var content = markupQuotes(
-            $.trim(text)
-            // remove line breaks
-            .replace(/\n|\r/g, '')
-            // replace leading BR
-            .replace(/^\s*(<br\/?>\s*)+/g, '')
-            // reduce long BR sequences
-            .replace(/(<br\/?>\s*){3,}/g, '<br><br>')
-            // remove split block quotes
-            .replace(/<\/blockquote>\s*(<br\/?>\s*)+<blockquote[^>]+>/g, '<br><br>')
-            // add markup for email addresses
-            .replace(regMailComplex, '<a href="mailto:$6">$2$3</a>')
+            insertEmoticons(
+                $.trim(text)
+                // remove line breaks
+                .replace(/\n|\r/g, '')
+                // replace leading BR
+                .replace(/^\s*(<br\/?>\s*)+/g, '')
+                // reduce long BR sequences
+                .replace(/(<br\/?>\s*){3,}/g, '<br><br>')
+                // remove split block quotes
+                .replace(/<\/blockquote>\s*(<br\/?>\s*)+<blockquote[^>]+>/g, '<br><br>')
+                // add markup for email addresses
+                .replace(regMailComplex, '<a href="mailto:$6">$2$3</a>')
+            )
         );
 
         return content;
@@ -110,33 +142,45 @@ define('io.ox/mail/view-detail',
 
     var openDocumentLink = function (e) {
         e.preventDefault();
-        location.hash = e.data.hash;
-        ox.launch('io.ox/files/main');
+        ox.launch('io.ox/files/main', { folder: e.data.folder, perspective: 'list' }).done(function () {
+            var app = this, folder = e.data.folder, id = e.data.id;
+            // switch to proper perspective
+            ox.ui.Perspective.show(app, 'list').done(function () {
+                // set proper folder
+                app.folder.set(folder).done(function () {
+                    app.getGrid().selection.set(id);
+                });
+            });
+        });
     };
 
+    // fix hosts (still need a configurable list on the backend)
+    // ox.serverConfig.hosts = ox.serverConfig.hosts.concat('appsuite-dev.open-xchange.com', 'ui-dev.open-xchange.com', 'ox6-dev.open-xchange.com', 'ox6.open-xchange.com');
+
     var isValidHost = function (url) {
-        var match = url.match(/^https?:\/\/([^\/]+)/i);
-        return match && match.length &&
-                _(ox.serverConfig.hosts).indexOf(match[1]) > -1;
+        var match = url.match(/^https?:\/\/([^\/#]+)/i);
+        return match && match.length && _(ox.serverConfig.hosts).indexOf(match[1]) > -1;
     };
 
-    var drawDocumentLink = function (href, title) {
-        var link, m, folder, id;
+    var drawDocumentLink = function (matches, title) {
+        var link, href, folder, id;
         // create link
         link = $('<a>', { href: '#' })
             .css({ textDecoration: 'none', fontFamily: 'Arial' })
             .append($('<span class="label label-info">').text(title));
+        // get values
+        href = matches[2];
+        folder = matches[3];
+        id = matches[4];
         // internal document?
         /* TODO: activate internal Links when files app is ready */
-        if (isValidHost(href) && ((m = href.match(regDocumentAlt)) && m.length) && false) {
+        if (isValidHost(href)) {
             // yep, internal
-            folder = m[3];
-            id = m[4];
             href = '#app=io.ox/files&perspective=list&folder=' + folder + '&id=' + id;
-            link.on('click', { hash: href }, openDocumentLink);
+            link.on('click', { hash: href, folder: folder, id: id }, openDocumentLink);
         } else {
             // nope, external
-            link.attr('href', $.trim(href));
+            link.attr({ href: matches[0], target: '_blank' });
         }
         return link;
     };
@@ -148,16 +192,11 @@ define('io.ox/mail/view-detail',
     var delayedRead = function (data, node) {
         setTimeout(function () {
             api.tracker.applyAutoRead(data);
-            ext.point('io.ox/mail/detail/notification').invoke('action', node, data);
             node = data = null;
         }, 0); // without visual transition
     };
 
-    var blockquoteMore, blockquoteClickOpen, blockquoteClickClose, blockquoteCollapsedHeight, mailTo;
-
-    blockquoteCollapsedHeight = function () {
-        return $.browser.chrome ? 57 : 60;
-    };
+    var blockquoteMore, blockquoteClickOpen, blockquoteClickClose, blockquoteCollapsedHeight = 57, mailTo;
 
     blockquoteMore = function (e) {
         e.preventDefault();
@@ -183,7 +222,7 @@ define('io.ox/mail/view-detail',
         }
         $(this).off('dblclick.close')
             .on('click.open', blockquoteClickOpen)
-            .stop().animate({ maxHeight: blockquoteCollapsedHeight() }, 300, function () {
+            .stop().animate({ maxHeight: blockquoteCollapsedHeight }, 300, function () {
                 $(this).addClass('collapsed-blockquote');
             });
         $(this).next().show();
@@ -210,7 +249,7 @@ define('io.ox/mail/view-detail',
         getContent: function (data) {
 
             if (!data || !data.attachments) {
-                return $();
+                return { content: $(), isLarge: false, type: 'text/plain' };
             }
 
             var att = data.attachments, source = '', type = 'text/plain',
@@ -242,10 +281,13 @@ define('io.ox/mail/view-detail',
 
                 // empty?
                 if (source === '') {
-                    return $('<div class="content">').append(
-                        $('<div class="alert alert-info">')
-                        .text(gt('This mail has no content'))
-                    );
+                    return {
+                        content: $('<div class="content">').append(
+                            $('<div class="alert alert-info">').text(gt('This mail has no content'))
+                        ),
+                        isLarge: false,
+                        type: 'text/html'
+                    };
                 }
 
                 // replace images on source level
@@ -322,28 +364,39 @@ define('io.ox/mail/view-detail',
                                 this.nodeValue = text.replace(/(\S{60})/g, '$1\u200B'); // zero width space
                             }
                             // some replacements
-                            if (((m = text.match(regDocument)) && m.length) || ((m = text.match(regDocumentAlt)) && m.length)) {
+                            if ((m = text.match(regDocument)) && m.length) {
                                 // link to document
                                 node.replaceWith(
-                                     $($.txt(m[1])).add(drawDocumentLink(m[2], gt('Document'))).add($.txt(m[3]))
+                                     $($.txt(m[1])).add(drawDocumentLink(m, gt('Document'))).add($.txt(m[5]))
+                                );
+                            } else if ((m = text.match(regDocumentAlt)) && m.length) {
+                                // link to document (new syntax)
+                                node.replaceWith(
+                                     $($.txt(m[1])).add(drawDocumentLink(m, gt('Document'))).add($.txt(m[6]))
                                 );
                             } else if ((m = text.match(regFolder)) && m.length) {
                                 // link to folder
                                 node.replaceWith(
-                                    $($.txt(m[1])).add(drawDocumentLink(m[2], gt('Folder'))).add($.txt(m[3]))
+                                    $($.txt(m[1])).add(drawDocumentLink(m, gt('Folder'))).add($.txt(m[4]))
                                 );
-                            } else if ((m = text.match(regLink)) && m.length && node.closest('a').length === 0) {
-                                if (((n = m[2].match(regDocument)) && n.length) || ((n = m[2].match(regDocumentAlt)) && n.length)) {
+                            } else if ((n = text.match(regLink)) && n.length && node.closest('a').length === 0) {
+                                if ((m = n[2].match(regDocument)) && m.length) {
                                     // link to document
                                     node.replaceWith(
-                                         $($.txt(m[1])).add(drawDocumentLink(n[2], gt('Document'))).add($.txt(m[3]))
+                                        $($.txt(m[1])).add(drawDocumentLink(m, gt('Document'))).add($.txt(m[3]))
                                     );
-                                } else if ((n = m[2].match(regFolder)) && n.length) {
+                                } else if ((m = n[2].match(regDocumentAlt)) && m.length) {
+                                    // link to document
+                                    node.replaceWith(
+                                        $($.txt(m[1])).add(drawDocumentLink(m, gt('Document'))).add($.txt(m[4]))
+                                    );
+                                } else if ((m = n[2].match(regFolder)) && m.length) {
                                     // link to folder
                                     node.replaceWith(
-                                        $($.txt(m[1])).add(drawDocumentLink(n[2], gt('Folder'))).add($.txt(n[3]))
+                                        $($.txt(m[1])).add(drawDocumentLink(m, gt('Folder'))).add($.txt(m[4]))
                                     );
                                 } else {
+                                    m = n;
                                     node.replaceWith(
                                         $($.txt(m[1] || '')).add(drawLink(m[2])).add($.txt(m[3]))
                                     );
@@ -390,7 +443,7 @@ define('io.ox/mail/view-detail',
                     content.find('blockquote').not(content.find('blockquote blockquote')).each(function () {
                         var node = $(this);
                         node.addClass('collapsed-blockquote')
-                            .css({ opacity: 0.75, maxHeight: blockquoteCollapsedHeight() })
+                            .css({ opacity: 0.75, maxHeight: blockquoteCollapsedHeight })
                             .on('click.open', blockquoteClickOpen)
                             .on('dblclick.close', blockquoteClickClose)
                             .after(
@@ -398,7 +451,7 @@ define('io.ox/mail/view-detail',
                                 .on('click', blockquoteMore)
                             );
                         setTimeout(function () {
-                            if (node.prop('scrollHeight') < blockquoteCollapsedHeight()) { // 3 rows a 20px line-height
+                            if ((node.prop('scrollHeight') - 3) <= node.prop('offsetHeight')) { // 3 rows a 20px line-height
                                 node.removeClass('collapsed-blockquote')
                                     .css('maxHeight', '')
                                     .off('click.open dblclick.close')
@@ -413,7 +466,7 @@ define('io.ox/mail/view-detail',
                 console.error('mail.getContent', e.message, e, data);
             }
 
-            return content;
+            return { content: content, isLarge: isLarge, type: type };
         },
 
         drawScaffold: function (baton, resolver) {
@@ -433,7 +486,7 @@ define('io.ox/mail/view-detail',
 
             var data = baton.data,
                 self = this,
-                node = $('<div class="mail-detail">'),
+                node = $('<section class="mail-detail">'),
                 container = $.createViewContainer(data, api)
                     .addClass('mail-detail-decorator')
                     .on('redraw', function (e, tmp) {
@@ -459,7 +512,6 @@ define('io.ox/mail/view-detail',
                     delayedRead(data, node);
                 }
 
-                // invoke extensions
                 ext.point('io.ox/mail/detail').invoke('draw', node, baton);
 
             } catch (e) {
@@ -642,9 +694,26 @@ define('io.ox/mail/view-detail',
         }())
     };
 
-    //extensions
+    // extensions
+
+    // inline links for each mail
+    ext.point('io.ox/mail/detail').extend(new links.InlineLinks({
+        index: 100,
+        id: 'inline-links',
+        ref: 'io.ox/mail/links/inline'
+    }));
 
     ext.point('io.ox/mail/detail').extend({
+        index: 200,
+        id: 'header',
+        draw: function (baton) {
+            var header = $('<header>');
+            ext.point('io.ox/mail/detail/header').invoke('draw', header, baton);
+            this.append(header);
+        }
+    });
+
+    ext.point('io.ox/mail/detail/header').extend({
         index: 100,
         id: 'contact-picture',
         draw: function (baton) {
@@ -668,13 +737,13 @@ define('io.ox/mail/view-detail',
         }
     });
 
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 110,
         id: 'receiveddate',
         draw: function (baton) {
             // some mails just have a sent_date, e.g. nested EMLs
             var data = baton.data;
-            var date = util.getDateTime(data.received_date || data.sent_date || 0);
+            var date = util.getDateTime(data.received_date || data.sent_date || 0, { filtertoday: true });
             this.append(
                 $('<div>').addClass('date list').text(_.noI18n(date))
             );
@@ -689,7 +758,7 @@ define('io.ox/mail/view-detail',
         win.search.start(query);
     }
 
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 120,
         id: 'fromlist',
         draw: function (baton) {
@@ -706,7 +775,7 @@ define('io.ox/mail/view-detail',
         }
     });
 
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 124,
         id: 'thread-position',
         draw: function (baton) {
@@ -726,7 +795,7 @@ define('io.ox/mail/view-detail',
         RED:        gt('Red'),
         BLUE:       gt('Blue'),
         GREEN:      gt('Green'),
-        GREY:       gt('Grey'),
+        GRAY:       gt('Gray'),
         PURPLE:     gt('Purple'),
         LIGHTGREEN: gt('Light green'),
         ORANGE:     gt('Orange'),
@@ -741,8 +810,8 @@ define('io.ox/mail/view-detail',
         return api.changeColor(e.data.data, e.data.color);
     }
 
-    ext.point('io.ox/mail/detail').extend({
-        index: 105,
+    ext.point('io.ox/mail/detail/header').extend({
+        index: 130,
         id: 'flag',
         draw: function (baton) {
             var data = baton.data,
@@ -772,15 +841,20 @@ define('io.ox/mail/view-detail',
         }
     });
 
-    ext.point('io.ox/mail/detail').extend({
-        index: 130,
+    ext.point('io.ox/mail/detail/header').extend({
+        index: 140,
         id: 'subject',
         draw: function (baton) {
+            // soft-break long words (like long URLs)
+            var subject = $.trim(baton.data.subject).replace(/(\S{20})/g, '$1\u200B');
             this.append(
-                $('<div class="subject clear-title">').append(
-                    $('<i class="icon-bookmark">'),
+                $('<div class="mail-detail-clear-left">'),
+                $('<div>')
+                .addClass('subject clear-title' + (subject === '' ? ' empty' : ''))
+                .append(
+                    $('<i class="icon-unread icon-circle">'),
                     // inject some zero width spaces for better word-break
-                    $.txt(_.noI18n($.trim(baton.data.subject) || '\u00A0')),
+                    $.txt(_.noI18n(subject || gt('No subject'))),
                     $('<span class="priority">').append(util.getPriority(baton.data))
                 )
             );
@@ -796,7 +870,7 @@ define('io.ox/mail/view-detail',
             }).draw.call(node, data);
     };
 
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 150,
         id: 'tocopy',
         draw: function (baton) {
@@ -811,6 +885,7 @@ define('io.ox/mail/view-detail',
 
             if (show) {
                 this.append(
+                    $('<div>').addClass('mail-detail-clear-left'),
                     container.append(
                         // TO
                         $('<span>').addClass('io-ox-label').append(
@@ -833,6 +908,26 @@ define('io.ox/mail/view-detail',
         }
     });
 
+    ext.point('io.ox/mail/detail/header').extend({
+        after: 'tocopy',
+        id: 'account',
+        draw: function (baton) {
+
+            if (!folder.is('unifiedfolder', baton.data.folder_id)) return;
+
+            this.find('.to-cc').prepend(
+                $('<span class="io-ox-label">').append(
+                    $.txt(gt('Account')),
+                    $.txt(_.noI18n('\u00A0\u00A0'))
+                ),
+                $('<span class="account-name">').text(
+                    _.noI18n(util.getAccountName(baton.data))
+                ),
+                $.txt(_.noI18n(' \u00A0 '))
+            );
+        }
+    });
+
     var drawAttachmentDropDown = function (node, label, data) {
         // use extension pattern
         var dd = new links.DropdownLinks({
@@ -882,7 +977,7 @@ define('io.ox/mail/view-detail',
         $(this).remove();
     }
 
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 160,
         id: 'attachments',
         draw: function (baton) {
@@ -931,12 +1026,76 @@ define('io.ox/mail/view-detail',
         }
     });
 
-    // inline links for each mail
-    ext.point('io.ox/mail/detail').extend(new links.InlineLinks({
-        index: 170,
-        id: 'inline-links',
-        ref: 'io.ox/mail/links/inline'
-    }));
+    /**
+     * @description actions for publication invitation mails
+     */
+    ext.point('io.ox/mail/detail/header').extend({
+        index: 199,
+        id: 'subscribe',
+        draw: function (baton) {
+            var data = baton.data, picture,
+                label = '',
+                pub = {},
+                pubtype = '';
+
+            //exists publication header
+            pub.url  = data.headers['X-OX-PubURL'] || '';
+            if (pub.url === '')
+                return false;
+            else {
+                //qualify data
+                pubtype = /^(\w+),(.*)$/.exec(data.headers['X-OX-PubType']) || ['', '', ''];
+                pub.module  = pubtype[1];
+                pub.type  = pubtype[2];
+                pub.name = _.first(_.last(pub.url.split('/')).split('?'));
+                pub.parent = require('io.ox/core/config').get('folder.' + pub.module);
+                pub.folder = '';
+                label = pub.module === 'infostore' ? gt('files') : gt(pub.module);
+                //hide mail content if invitaion
+                //dom
+                var $actions, $appointmentInfo, $box;
+                $('<div class="well">').append(
+                    $('<span class="invitation">').text(gt('Someone shared a folder with you. Would you like to subscribe those %1$s?', label)),
+                    $("<br>"),
+                    $appointmentInfo = $('<div class="appointmentInfo">'),
+                    $actions = $('<div class="subscription-actions">')
+                ).appendTo(this);
+                $actions.append(
+                    $('<button class="btn" data-action="show">').text(gt('Show original publication')),
+                    "&nbsp;",
+                    $('<button class="btn btn-primary" data-action="subscribe">').text(gt('Subscribe'))
+                );
+                //actions
+                $actions.on('click', 'button', function (e) {
+                    var button = $(e.target),
+                        notifications = require('io.ox/core/notifications');
+                    //disble button
+                    if (button.data('action') === 'show') {
+                        window.open(pub.url, '_blank');
+                    } else {
+                        $(e.target).attr('disabled', 'disabled');
+                        notifications.yell('info', gt('Adding subscription. This may take some seconds...'));
+                        var self = this,
+                            opt = opt || {};
+                        //create folder; create and refresh subscription
+                        require(['io.ox/core/pubsub/api']).done(function (pubsubApi) {
+                            pubsubApi.autoSubscribe(pub.module, pub.name, pub.url).then(
+                                function success(data) {
+                                    notifications.yell('success', gt("Created private folder '%1$s' in %2$s and subscribed succesfully to shared folder", pub.name, pub.module));
+                                    //refresh folder views
+                                    folder.trigger('update');
+                                },
+                                function fail(data) {
+                                    notifications.yell('error', data.error || gt('An unknown error occurred'));
+                                }
+                            );
+                        });
+                    }
+                });
+                this.append($box);
+            }
+        }
+    });
 
     // inline links for entire thread
     ext.point('io.ox/mail/thread').extend(new links.DropdownLinks({
@@ -945,7 +1104,7 @@ define('io.ox/mail/view-detail',
         ref: 'io.ox/mail/links/inline'
     }));
 
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 90,
         id: 'phishing-warning',
         draw: function (baton) {
@@ -971,7 +1130,7 @@ define('io.ox/mail/view-detail',
     });
 
     // TODO: remove click handler out of inner closure
-    ext.point('io.ox/mail/detail').extend({
+    ext.point('io.ox/mail/detail/header').extend({
         index: 195,
         id: 'externalresources-warning',
         draw: function (baton) {
@@ -1004,49 +1163,61 @@ define('io.ox/mail/view-detail',
         }
     });
 
+    function findFarthestElement(memo, node) {
+        var pos;
+        if (node.css('position') === 'absolute' && (pos = node.position())) {
+            memo.x = Math.max(memo.x, pos.left + node.width());
+            memo.y = Math.max(memo.y, pos.top + node.height());
+            memo.found = true;
+        }
+        return memo;
+    }
+
     ext.point('io.ox/mail/detail').extend({
-        index: 200,
+        index: 300,
         id: 'content',
         draw: function (baton) {
 
-            var data = baton.data;
+            var data = baton.data, content = that.getContent(data);
 
-            this.attr('data-cid', data.folder_id + '.' + data.id).append(
-                that.getContent(data),
-                $('<div>').addClass('mail-detail-clear-both')
+            this.append(
+                $('<article>').attr({
+                    'data-cid': data.folder_id + '.' + data.id,
+                    'data-content-type': content.type
+                })
+                .addClass(
+                    // html or text mail
+                    content.type === 'text/html' ? 'text-html' : 'text-plain'
+                )
+                .addClass(
+                    // assuming touch-pad/magic mouse for macos
+                    // chrome & safari do a good job; firefox is not smooth
+                    // ios means touch devices; that's fine
+                    _.device('(macos && (chrome|| safari)) || ios') ? 'horizontal-scrolling' : ''
+                )
+                .append(
+                    content.content,
+                    $('<div class="mail-detail-clear-both">')
+                )
             );
 
             var content = this.find('.content');
 
             setTimeout(function () {
-                var scrollHeight = content.get(0).scrollHeight;
-
-                if (scrollHeight >= content.height()) { //Bug 22756: FF18 is behaving oddly correct, but impractical
-                    var lowestElement = _($(content).find('*'))
-                        .chain()
-                        .filter(function (elem) { return $(elem).position() && $(elem).css('position') === 'absolute'; })
-                        .max(function (elem) { return $(elem).position().top + $(elem).height(); })
-                        .value();
-                    if (lowestElement !== -Infinity) {
-                        scrollHeight = Math.round($(lowestElement).position().top + $(lowestElement).height());
-                    }
+                var farthest = { x: content.get(0).scrollWidth, y: content.get(0).scrollHeight, found: false },
+                    width = content.width(), height = content.height();
+                if (!content.isLarge && (farthest.x >= width || farthest.y >= height)) { // Bug 22756: FF18 is behaving oddly correct, but impractical
+                    farthest = _.chain($(content).find('*')).map($).reduce(findFarthestElement, farthest).value();
                 }
-                if (scrollHeight > content.height()) {
-                    content.css('height', scrollHeight + 'px');
+                // only do this for absolute elements
+                if (farthest.found) {
+                    if (farthest.x > width) content.css('width', Math.round(farthest.x) + 'px');
+                    if (farthest.y > height) content.css('height', Math.round(farthest.y) + 'px');
                 }
                 content = null;
             }, 0);
         }
     });
 
-    //Extensionpoint to remove read mails in notification Area
-    ext.point('io.ox/mail/detail/notification').extend({
-        index: 100,
-        id: 'update-notification',
-        action: function (data) {
-            api.trigger('remove-unseen-mails', [data]);
-        }
-    });
-
     return that;
 });
