@@ -21,7 +21,7 @@ define('io.ox/portal/main',
      'io.ox/portal/widgets',
      'gettext!io.ox/portal',
      'settings!io.ox/portal',
-     'less!io.ox/portal/style.css',
+     'less!io.ox/portal/style.less',
      'apps/io.ox/core/tk/jquery-ui.min.js'
     ], function (ext, userAPI, date, manifests, dialogs, widgets, gt, settings) {
 
@@ -62,13 +62,18 @@ define('io.ox/portal/main',
         id: 'header',
         index: 100,
         draw: function (baton) {
+            var $btn = $();
+            if (_.device('!small')) {
+                // please no button
+                $btn = $('<button class="btn btn-primary pull-right">')
+                    .attr('data-action', 'customize')
+                    .text(gt('Customize this page'))
+                    .on('click', openSettings);
+            }
             this.append(
                 $('<div class="header">').append(
                     // button
-                    $('<button class="btn btn-primary pull-right">')
-                        .attr('data-action', 'customize')
-                        .text(gt('Customize this page'))
-                        .on('click', openSettings),
+                    $btn,
                     // greeting
                     $('<h1 class="greeting">').append(
                         baton.$.greeting = $('<span class="greeting-phrase">'),
@@ -105,7 +110,7 @@ define('io.ox/portal/main',
                 'data-widget-id': baton.model.get('id'),
                 'data-widget-type': baton.model.get('type')
             })
-            .addClass('widget pending')
+            .addClass('widget pending' + (baton.model.get('inverse') ? ' inverse' : ''))
             .append(
                 $('<h2 class="title">').text('\u00A0')
             );
@@ -245,12 +250,19 @@ define('io.ox/portal/main',
                 point.invoke('preview', node, baton);
                 node.removeClass('pending error-occurred');
             })
-            .fail(function (errorData) {
+            .fail(function (e) {
+                // special return value?
+                if (e === 'remove') {
+                    widgets.remove(baton.model);
+                    node.remove();
+                    return;
+                }
+                // show error message
                 node.find('.content').remove();
                 node.append(
                     $('<div class="content error">').append(
                         $('<div>').text(gt('An error occurred. The message was:')),
-                        $('<div class="italic">').text(errorData.error),
+                        $('<div class="italic">').text(e.error),
                         '<br />',
                         $('<a class="solution">').text(gt('Click to try again.')).on('click', function () {
                             node.addClass('pending');
@@ -258,6 +270,7 @@ define('io.ox/portal/main',
                         })
                     )
                 );
+                point.invoke('error', node, e, baton);
                 node.removeClass('pending');
             });
     }
@@ -357,6 +370,13 @@ define('io.ox/portal/main',
             // add side popup
             sidepopup.delegate(appBaton.$.widgets, '.item, .content.pointer, .action.pointer', openSidePopup);
 
+            // add -webkit-overflow-scroll only for iOS to enable momentum scroll
+            // (will cause errors on android chrome)
+            // TODO: avoid device specific inline css fixes
+            if (_.browser.iOS) {
+                $('.io-ox-portal').css('-webkit-overflow-scrolling', 'touch');
+            }
+
             // make sortable, but not for Touch devices
             if (!Modernizr.touch) {
                 appBaton.$.widgets.sortable({
