@@ -21,7 +21,7 @@ define('io.ox/portal/widgets',
 	'use strict';
 
 	// use for temporary hacks
-	var DEV_PLUGINS = ['plugins/portal/contacts/register', 'plugins/portal/files/register'];
+	var DEV_PLUGINS = ['plugins/portal/mail/register', 'plugins/portal/flickr/register'];
 
     // application object
     var availablePlugins = _(manifests.manager.pluginsFor('portal')).uniq().concat(DEV_PLUGINS),
@@ -38,8 +38,13 @@ define('io.ox/portal/widgets',
 
     var api = {
 
+        // for demo/debugging
+        addPlugin: function (plugin) {
+            availablePlugins = availablePlugins.concat(plugin);
+        },
+
         getAvailablePlugins: function () {
-            return availablePlugins;
+            return _(availablePlugins).uniq();
         },
 
         getCollection: function () {
@@ -53,35 +58,48 @@ define('io.ox/portal/widgets',
         },
 
         getSettings: function () {
+
+            var prot = {};
+
+            _(settings.get('widgets/protected')).each(function (obj, id) {
+                obj.protectedWidget = true;
+                prot[id] = obj;
+            });
+
             return _(settings.get('widgets/user', {}))
                 .chain()
+                .extend(prot)
                 // map first since we need the object keys
                 .map(function (obj, id) {
+
                     obj.id = id;
                     obj.type = id.split('_')[0];
                     obj.props = obj.props || {};
+                    obj.inverse = _.isUndefined(obj.inverse) ? false : obj.inverse;
+                    obj.enabled = _.isUndefined(obj.enabled) ? true : obj.enabled;
+
                     return obj;
                 })
                 .filter(function (obj) {
-                    return _(availablePlugins).contains(obj.plugin) || _(allTypes).contains(obj.type);
+                    return _(api.getAvailablePlugins()).contains(obj.plugin) || _(allTypes).contains(obj.type);
                 })
                 .value();
         },
 
         loadAllPlugins: function () {
-            return require(availablePlugins);
+            return require(api.getAvailablePlugins());
         },
 
         loadUsedPlugins: function () {
             var usedPlugins = collection.pluck('plugin'),
-                dependencies = _(availablePlugins).intersection(usedPlugins);
+                dependencies = _(api.getAvailablePlugins()).intersection(usedPlugins);
             return require(dependencies).done(function () {
                 api.removeDisabled();
             });
         },
 
         getAllTypes: function () {
-            return _.chain(availablePlugins.concat(allTypes))
+            return _.chain(api.getAvailablePlugins().concat(allTypes))
                 .map(function (id) {
                     var type = id.replace(/^plugins\/portal\/(\w+)\/register$/, '$1');
                     return ext.point('io.ox/portal/widget/' + type + '/settings').options();
@@ -96,10 +114,8 @@ define('io.ox/portal/widgets',
         },
 
         getUsedTypes: function () {
-            return collection.pluck('plugin')
-                .map(function (id) {
-                    return id.replace(/^plugins\/portal\/(\w+)\/register$/, '$1');
-                });
+            // mmmh, chain() on collection seems broken
+            return _(collection.pluck('type')).uniq().sort();
         },
 
         getColors: function () {
@@ -110,25 +126,33 @@ define('io.ox/portal/widgets',
             return data.title || (data.props ? (data.props.description || data.props.title) : '') || fallback || '';
         },
 
-        add: function (type, plugin, props) {
+        add: function (type, options) {
 
             // find free id
-            var widgets = settings.get('widgets/user', {}),
-                widget,
-                i = 0, id = type + '_0',
+            var widgets = _(settings.get('widgets/user', {})).extend(settings.get('widgets/protected', {})),
+                widget, i = 0, id = type + '_0',
                 colors = api.getColors();
 
+            options = _.extend({
+                color: colors[_.random(colors.length - 1)],
+                enabled: true,
+                inverse: false,
+                plugin: type,
+                props: {}
+            }, options || {});
+
             while (id in widgets) {
                 id = type + '_' + (++i);
             }
 
             widget = {
-                color: colors[_.random(colors.length - 1)],
-                enabled: true,
+                color: options.color,
+                enabled: options.enabled,
+                inverse: options.inverse,
                 id: id,
-                index: collection.length,
-                plugin: 'plugins/portal/' + (plugin || type) + '/register',
-                props: props || {},
+                index: 0, // otherwise not visible
+                plugin: 'plugins/portal/' + options.plugin + '/register',
+                props: options.props,
                 type: type
             };
 
@@ -137,6 +161,10 @@ define('io.ox/portal/widgets',
             collection.add(widget);
         },
 
+        remove: function (model) {
+            collection.remove(model);
+        },
+
         removeDisabled: function () {
             collection.remove(
                 collection.filter(function (model) {
@@ -150,6 +178,9 @@ define('io.ox/portal/widgets',
             // get latest values
             var widgets = {};
             collection.each(function (model) {
+                if (model.get('protectedWidget')) {
+                    return;
+                }
                 var id = model.get('id');
                 widgets[id] = model.toJSON();
                 delete widgets[id].baton;
@@ -175,7 +206,7 @@ define('io.ox/portal/widgets',
          * @return - a deffered object with the save request
          */
         save: function (widgetList) {
-            var obj = this.toJSON(), old_state = obj;
+            var obj = this.toJSON(), old_state = obj, self = this;
 
             // update all indexes
             widgetList.children().each(function (index) {
@@ -187,17 +218,18 @@ define('io.ox/portal/widgets',
             this.update(obj);
             collection.trigger('sort');
 
-            return settings.set('widgets/user', this).save()
-            .done(function () {
-                notifications.yell('success', gt("Settings saved."));
-            })
-            .fail(function () {
-                //reset old state
-                this.update(old_state);
-                collection.trigger('sort');
-                widgetList.sortable('cancel');
-                notifications.yell('error', gt("Could not save settings."));
-            });
+            return settings.set('widgets/user', this).save().then(
+                function () {
+                    notifications.yell('success', gt("Settings saved."));
+                },
+                function () {
+                    //reset old state
+                    self.update(old_state);
+                    collection.trigger('sort');
+                    widgetList.sortable('cancel');
+                    notifications.yell('error', gt("Could not save settings."));
+                }
+            );
         }
     };
 
@@ -213,6 +245,10 @@ define('io.ox/portal/widgets',
     });
 
     collection.on('remove', function (model) {
+        if (model.get("protectedWidget")) {
+            // Don't you dare!
+            return;
+        }
         settings.remove('widgets/user/' + model.get('id')).save();
     });
 
