@@ -266,6 +266,12 @@ define('plugins/notifications/calendar/register',
                 .on('new-invites', function (e, invites) {
                     var tmp = [];
 
+                    // just for the moment as reminder view blocks whole screen
+                    // will reenable the view later with new design
+                    if (_.device('small && touch')) {
+                        return;
+                    }
+
                     $.when.apply($,
                         _(invites).map(function (invite) {
                             var inObj = {
@@ -301,48 +307,44 @@ define('plugins/notifications/calendar/register',
                 .on("confirmation-changed", removeInvites)
                 .on('remove-calendar-notifications', removeInvites)
                 .getInvites();
-            
+
             function removeInvites(e, invites) {
               //make sure we have an array
                 invites = invites ? [].concat(invites) : [];
-                var removed = false;
                 _(invites).each(function (invite) {
                     for (var i = 0; InviteNotifications.collection.length > i; i++) {
                         var model = InviteNotifications.collection.models[i];
                         if (model.attributes.data.id === invite.id && model.attributes.data.folder_id === (invite.folder || invite.folder_id)) {
                             InviteNotifications.collection.remove(model);
-                            removed = true;
                         }
                     }
                 });
-                if (removed) {
-                    InviteNotifications.collection.trigger('remove');
-                }
             }
-            
+
             function removeReminders(e, reminders) {
                 //make sure we have an array
                 reminders = reminders ? [].concat(reminders) : [];
-                var removed = false;
                 _(reminders).each(function (reminder) {
                     for (var i = 0; ReminderNotifications.collection.length > i; i++) {
                         var model = ReminderNotifications.collection.models[i];
                         if (model.attributes.caldata.id === reminder.id && model.attributes.caldata.folder_id === (reminder.folder || reminder.folder_id)) {
                             ReminderNotifications.collection.remove(model);
-                            removed = true;
                         }
                     }
                 });
-                if (removed) {
-                    ReminderNotifications.collection.trigger('remove');
-                }
             }
 
             reminderApi
                 .on('reminder-calendar', function (e, reminder) {
+                    // just for the moment as reminder view blocks whole screen
+                    // will reenable the view later with new design
+                    if (_.device('small && touch')) {
+                        return;
+                    }
+
                     var tmp = [],
                         counter = reminder.length;
-                    
+
                     _(reminder).each(function (remObj, index) {
                         var obj = {
                             id: remObj.target_id,
@@ -359,13 +361,13 @@ define('plugins/notifications/calendar/register',
                                 remdata: remObj,
                                 caldata: data
                             };
-                            
+
                             // do not add user suppressed ('remind me later') reminders
                             if (ReminderNotifications.collection.hidden.length === 0 || _.indexOf(ReminderNotifications.collection.hidden, _.cid(remObj)) === -1) {
                                 tmp.push(inObj);
                             }
                             counter--;
-                            
+
                             if (counter === 0) {//all data processed. Update Collection
                                 ReminderNotifications.collection.reset(tmp);
                             }
