@@ -43,17 +43,33 @@ define('plugins/notifications/mail/register',
             )
         );
     }
+    
+    function showMail(obj, node, model) {
+        
+        // fetch plain text mail; don't use cache
+        api.get(obj, false).done(function (data) {
+            //update model
+            model.set(data);
+            //draw
+            drawItem(node, data);
+        }).fail(function () {
+            node.append(
+                $.fail(gt('Couldn\'t load that email.'), function () {
+                    showMail(obj, node, model);
+                })
+            );
+        });
+    }
 
     ext.point('io.ox/core/notifications/mail/item').extend({
         draw: function (baton) {
-
-            var obj = _.extend(api.reduce(baton.model.toJSON()), { unseen: true, view: 'text' }),
-                node = this;
-
-            // fetch plain text mail; don't use cache
-            api.get(obj, false).done(function (data) {
-                drawItem(node, data);
-            });
+            //to avoid unnecessary requests check if the model is already complete, if not get it and fill in the missing data
+            if (baton.model.get('attachments')) {//attachments contains the actual text
+                drawItem(this, baton.model.attributes);
+            } else {//mail model not complete
+                var obj = _.extend(api.reduce(baton.model.toJSON()), { unseen: true, view: 'text' });
+                showMail(obj, this, baton.model);
+            }
         }
     });
 
@@ -64,23 +80,19 @@ define('plugins/notifications/mail/register',
         events: {
             'click [data-action="open-app"]': 'openApp',
             'click .item': 'openMail',
-            'dispose .item': 'removeNotification' //triggered by detailView
+            'dispose .item': 'removeNotification' //seems to be unused
         },
 
         initialize: function () {
             var self = this;
-            this.model = new Backbone.Model({ unread: 0 });
             this.collection.on('reset add remove', this.render, this);
-            api.on('unseen-mail', function (e, data) {
-                self.model.set('unread', _(data).size());
-            });
         },
 
         render: function () {
             var i = 0, $i = Math.min(this.collection.size(), 3), baton;
             baton = ext.Baton({ view: this });
             ext.point('io.ox/core/notifications/mail/header').invoke('draw', this.$el.empty(), baton);
-
+            
             for (; i < $i; i++) {
                 baton = ext.Baton({ model: this.collection.at(i), view: this });
                 ext.point('io.ox/core/notifications/mail/item').invoke('draw', this.$('.notifications'), baton);
@@ -93,22 +105,31 @@ define('plugins/notifications/mail/register',
             var cid = $(e.currentTarget).data('cid'),
                 overlay = $('#io-ox-notifications-overlay'),
                 sidepopup = overlay.prop('sidepopup'),
-                self = this;
+                cleanUp = function (e, mails) {
+                    _(mails).each(function (obj) {
+                        if (cid === _.cid(obj)) {
+                            e.data.popup.close();
+                        }
+                    });
+                };
             // toggle?
             if (sidepopup && cid === overlay.find('[data-cid]').data('cid')) {
                 sidepopup.close();
             } else {
+                
                 // fetch proper mail first
                 api.get(_.cid(cid)).done(function (data) {
                     require(['io.ox/core/tk/dialogs', 'io.ox/mail/view-detail'], function (dialogs, view) {
                         // open SidePopup without array
-                        new dialogs.SidePopup({ arrow: false, side: 'right' })
+                        var detailPopup = new dialogs.SidePopup({ arrow: false, side: 'right' })
                             .setTarget(overlay.empty())
                             .on("close", function () {
                                 overlay.trigger("mail-detail-closed");
+                                api.off('delete', cleanUp);
                             })
                             .show(e, function (popup) {
                                 popup.append(view.draw(data));
+                                api.on('delete', {popup: detailPopup}, cleanUp);//if mail gets deleted we must close the sidepopup or it will show a blank page
                             });
                     });
                 });
@@ -135,8 +156,10 @@ define('plugins/notifications/mail/register',
             }
         }
     });
-
-    /* Mail notifications disabled for release-7.0.1 see Bug 24938 and 24953
+    
+    //minicache to store mails that are seen already
+    //if mails are added to the notification collection after seen is triggered they are never set to seen correctly otherwise
+    var seenMails = {};
 
     ext.point('io.ox/core/notifications/register').extend({
         id: 'mail',
@@ -144,13 +167,30 @@ define('plugins/notifications/mail/register',
         register: function (controller) {
             var notifications = controller.get('io.ox/mail', NotificationsView);
 
-            function addMails(e, mails) {//adds mails to notificationview
+            function addMails(e, mails, unseenMails) {//adds mails to notificationview and remove elsewhere read ones
                 var mailsToAdd = [];
-                for (var i = 0; i < mails.length; i++) { //check if models for this mail are already present
-                    if (!(notifications.collection._byId[mails[i].id])) {
+                //add new ones
+                for (var i = 0; i < mails.length; i++) { //check if models for this mail are already present and not seen
+                    if (!(notifications.collection._byId[mails[i].id]) && !(seenMails[mails[i].id])) {
                         mailsToAdd.push(mails[i]);
                     }
                 }
+                //remove elsewhere read ones
+                var found  = [],
+                    unseenArray = [],
+                    mailsToRemove;
+                _(notifications.collection.models).each(function (mail) {
+                    found.push(mail.get('id'));
+                });
+                _(unseenMails).each(function (mail) {
+                    unseenArray.push(mail.id);
+                });
+                mailsToRemove = _.difference(found, unseenArray);//mails in the collection that are not unseen need to be removed
+
+                _(mailsToRemove).each(function (id) {
+                    notifications.collection.remove(notifications.collection._byId[id]);
+                    seenMails[id] = true;//make sure this mail is not added again because it's seen already
+                });
                 _(mailsToAdd.reverse()).each(function (mail) {
                     notifications.collection.unshift(new Backbone.Model(mail), { silent: true });
                 });
@@ -158,26 +198,49 @@ define('plugins/notifications/mail/register',
             function removeMails(e, mails) {//removes mails from notificationview
                 _(mails).each(function (mail) {
                     notifications.collection.remove(notifications.collection._byId[mail.id]);
+                    seenMails[mail.id] = true;//make sure this mail is not added again because it's seen already
+                });
+            }
+            function removeFolder(e, folder) {//removes mails of a whole folder from notificationview
+                _(notifications.collection.models).each(function (mail) {
+                    if (mail.get('folder_id') === folder) {
+                        notifications.collection.remove(notifications.collection._byId[mail.id]);
+                        seenMails[mail.id] = true;//make sure this mail is not added again because it's seen already
+                    }
                 });
             }
 
-            api.on('new-mail', function (e, mails) {
-                addMails(e, mails);
+            api.on('new-mail', function (e, mails, unseenMails) {
+                if (!_.isArray(mails)) {
+                    mails = [].concat(mails);
+                }
+                addMails(e, mails, unseenMails);
                 notifications.collection.trigger('reset');
             });
-            api.on('add-unseen-mails', function (e, mails) {
-                addMails(e, mails);
-                notifications.collection.trigger('add');
+            api.on('move', function (e, mails, newFolder) {
+                if (!_.isArray(mails)) {
+                    mails = [].concat(mails);
+                }
+                if (newFolder !== 'default0/INBOX') {//moved out of Inbox
+                    removeMails(e, mails);
+                }
             });
-            api.on('remove-unseen-mails', function (e, mails) {
-                removeMails(e, mails);
-                notifications.collection.trigger('remove');
+            
+            api.on('delete seen', function (e, mails) {
+                if (!_.isArray(mails)) {
+                    mails = [].concat(mails);
+                }
+                if (mails.length > 0 && !mails[0].id) {//check if we have a folder seen action
+                    removeFolder(e, mails[0].folder);
+                } else {
+                    removeMails(e, mails);
+                }
+                
             });
 
             api.checkInbox();
         }
     });
-    */
 
     return true;
 });
